setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study1 <- read.dta('Study1.dta')

# Convert into csv-File
write.csv(study1, "C:/Users/User/Desktop/Study 1/Study1.csv", row.names=TRUE)

# possibly create Figure1 that contains all 6 panels
postscript(file="Figure1.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(3,3))

########## Figure 1A ##########
attach(study1)
order <- order(dclass)
order.class <- dclass[order]
donate100 <- ddonate*100
order.donate <- donate100[order]

plot(order.class, order.donate,
main="Proportion of donating households\n(per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Percent", 
mgp=c(2.65,1,0),
xaxs="i",
xlim = c(0.5, 10), 
ylim = c(0, 100), type = "l", lwd=1, bty="l", yaxs="i", xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1.0)
mtext("A",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2)
points(order.class, order.donate,cex=0.7, pch=20)
detach(study1)


########## Figure 1B ##########
library(locfit)
ttt <- locfit(hhdonate~c_hhclass, family="binomial", data=study1, alpha=1)
ttt2 <-predict(ttt, data.frame(c_hhclass = seq(-2.76, 3.27, 0.01)))
ttt2_100 <- ttt2*100
plot(seq(-2.76, 3.27,0.01), ttt2_100, main="Probability of donating\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percent", 
xlim = c(-3, 3), 
mgp=c(2.65,1,0),
ylim = c(0, 100),
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("B",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )


########## Figure 1C #########
x <- seq(-2.76,3.27,0.01)
y <- 1/(1+exp(-(0.1636+0.7264*x-0.0265*x^2)))
y100 <- y*100
plot(x, y100, main="Predicted values\nof the probability of donating", 
     xlab="Standardized obj. social class", ylab="Percent", 
     xlim = c(-3, 3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 100),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("C",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )


########## Figure 1D #########
attach(study1)
order <- order(dclass)
order.class <- dclass[order]
order.relative <- drelative[order]
order.relativeA <- drelativeA[order]

plot(order.class, order.relative,
main="Relative amount of donations\n(means per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Percentage of\ncontributed household income", 
mgp=c(2.3,1,0),
xaxs="i",
xlim = c(0.5, 10), 
ylim = c(0, 2), type = "l", lwd=1, bty="l", yaxs="i", lty=2, xaxp=c(1,10,9), yaxp=c(0,2,4), cex.lab = 1, cex.axis = 1, cex.main=1)
lines(order.class, order.relativeA,
type = "l", lwd=1, lty=1)
legend (1.5, 2, c("donating households", "all households"), lty=c(2,1))
mtext("D",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )
points(order.class, order.relative,cex=0.7, pch=20)
points(order.class, order.relativeA,cex=0.7, pch=20)
detach(study1)


########## Figure 1E ###############
loamdon <- with(study1, loess(hhrelative ~ c_hhclass, span=0.8, degree=1))
amdon <- predict(loamdon, data.frame(c_hhclass = seq(-2.42, 3.27, 0.01)))
loamall <- with(study1, loess(hhrelativeA ~ c_hhclass, span=0.8, degree=1))
amall <- predict(loamall, data.frame(c_hhclass = seq(-2.76, 3.27, 0.01)))

plot(seq(-2.42, 3.27, 0.01),amdon, 
main="Relative amount of donations\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percentage of\ncontributed household income", 
mgp=c(2.3,1,0),
xlim = c(-3, 3), 
ylim = c(0, 2), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", yaxp=c(0,2,4), lty=2, cex.lab = 1, cex.axis = 1, cex.main=1)
lines(seq(-2.76, 3.27, 0.01),amall,
type = "l", lwd=1, lty=1)
legend (-2.5, 2, c("donating households", "all households"), lty=c(2,1))
mtext("E",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )


########## Figure 1F ###############
xdon <- seq(-2.42,3.27,0.01)
ydon <- 0.6334+0.0054*xdon+0.1335*xdon^2
xall <- seq(-2.76,3.27,0.01)
yall <- 0.3357+0.1579*xall+0.0730*xall^2

plot(xdon,ydon, 
     main="Predicted values\nof the relative amount of donations", 
     xlab="Standardized obj. social class", ylab="Percentage of\ncontributed household income", 
     mgp=c(2.3,1,0),
     xlim = c(-3, 3), 
     ylim = c(0, 2), 
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", yaxp=c(0,2,4), lty=2, cex.lab = 1, cex.axis = 1, cex.main=1)
lines(xall,yall,
      type = "l", lwd=1, lty=1)
legend (-2.5, 2, c("donating households", "all households"), lty=c(2,1))
mtext("F",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )


dev.off()
