/*                                                                       */
/* -----        How to customize the paths and options:   -----          */
/* -----        Some further explanations:                -----          */                                                                           
/*  The following                                                        */                              
/*                                                                       */                 
/*  global macros (in stata),                                            */                                          
/*                                                                       */                 
/*  define the locations for the original SOEP DATA, the directory       */                                                                               
/*  for temporary files and the destination of the resulting data file.  */                                                                                    
/*                                                                       */                 
/*  MY_IN_PATH   = "path/to/your/SOEP/directory/"                        */                                                              
/*  MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"       */                                                                               
/*  MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"      */                                                                                
/*                                                                       */                 
/*  The correct specification of the path depends on your Operating      */                                                                                
/*  System and on your SOEP installation, but be sure to use a           */                                                                           
/*  TRAILING backslash ("\", within Windows) or a                        */                                                              
/*  TRAILING forward slash ("/", within Unix/Linux).                     */                                                                 
/*                                                                       */                 
/*  You can also change the name for the resulting data file with the    */                                                                                  
/*  variable MY_OUT_FILE and the name for the log file (only with        */                                                                              
/*  stata, variable MY_LOG_FILE).                                        */                                              
/* ----------------------------------------------------------------      */                                                                                


/* -----   Here you can customize the paths and options:   ----- */

global MY_IN_PATH   = "path/to/your/SOEP/directory/"                                                             
global MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"                                                                             
global MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"

global MY_OUT_FILE  ${MY_OUT_PATH}\Study 1\Study1.dta
global MY_LOG_FILE  ${MY_OUT_PATH}\Study 1\Study1_data_preparation.log

log using "${MY_LOG_FILE}", text replace
set more off

***** To get access to the SOEP data, you have to conclude a data distribution contract with DIW Berlin ***
***** For more details, see http://www.diw.de/en/diw_02.c.222516.en/data.html *****************************
***********************************************************************************************************
***** For our analyses, we used data for years 1984-2012, Version 29, 2013 ********************************
***********************************************************************************************************



/* ----------------[ automatically pull PPFAD ]----------------- */

use    hhnr    persnr  sex  gebjahr psample ///
       bahhnr  zhhnr ///  
       banetto znetto /// 
       bapop   zpop ///
using  "${MY_IN_PATH}ppfad.dta"

/* --------------[ balanced / unbalanced design ]--------------- */

keep if ( ( banetto > 0 & banetto < 40 ) | ( znetto > 0 & znetto < 40 ) )

/* -----------------[ private housholds only.]------------------ */

/* -- start comment
keep if ( ( bapop == 1 | bapop == 2 ) | ( tpop == 1 | tpop == 2 ) |
          ( upop == 1 | upop == 2 ) | ( vpop == 1 | vpop == 2 ) |
          ( wpop == 1 | wpop == 2 ) | ( zpop == 1 | zpop == 2 ) );
*/
/* -----------------------[ sort ppfad ]------------------------ */

sort persnr
save "${MY_TEMP_PATH}ppfad.dta", replace
clear

/* -----------------[ automatically pull PHRF ]----------------- */

use    hhnr    persnr  prgroup   ///
       baphrf  zphrf  ///
using  "${MY_IN_PATH}phrf.dta"

sort  persnr
save  "${MY_TEMP_PATH}phrf.dta", replace
clear

/* --------------[ automatically create pmaster ]--------------- */

use    "${MY_TEMP_PATH}ppfad.dta"
merge  persnr   ///
using  "${MY_TEMP_PATH}phrf.dta"

drop   if _merge == 2
drop   _merge
erase  "${MY_TEMP_PATH}ppfad.dta"
erase  "${MY_TEMP_PATH}phrf.dta"
sort   persnr
save   "${MY_TEMP_PATH}pmaster.dta", replace


/* ----------------------( pull zpequiv )----------------------- */

use    hhnr    zhhnr   persnr     ///
       d1110109 d1110509 d1110609 h1110109   ///
using "${MY_IN_PATH}zpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}zpequiv.dta", replace
clear

/* -----------------------( pull zpgen )------------------------ */

use    hhnr    zhhnr   persnr     ///
       siops09 isced09   ///
using "${MY_IN_PATH}zpgen.dta"

sort persnr
save "${MY_TEMP_PATH}zpgen.dta", replace
clear

/* ----------------------( pull bapequiv )---------------------- */

use    hhnr    bahhnr  persnr     ///
       i1110210   ///
using "${MY_IN_PATH}bapequiv.dta"

sort persnr
save "${MY_TEMP_PATH}bapequiv.dta", replace
clear

/* ------------------------( pull bap )------------------------- */

use    hhnr    bahhnr  persnr     ///
       bap12001 bap12002   ///
using "${MY_IN_PATH}bap.dta"

sort persnr
save "${MY_TEMP_PATH}bap.dta", replace
clear


/* -----------------( Now merge all together )------------------ */

use   "${MY_TEMP_PATH}pmaster.dta"
erase "${MY_TEMP_PATH}pmaster.dta"

/* -----------( merge together by person: ALL Waves )----------- */


/* ----------------------( merge ZPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}zpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}zpequiv.dta"

/* -----------------------( merge ZPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}zpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}zpgen.dta"

/* ---------------------( merge BAPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bapequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bapequiv.dta"

/* ------------------------( merge BAP )------------------------ */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bap.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bap.dta"


/* --------------------------( Merging done! )-------------------------- */

label data "SOEPINFO: Magic at Work! http://panel.gsoep.de/soepinfo/"
save  "${MY_OUT_FILE}", replace
desc


/* ----------( Drop variables that are not needed for calculations )------------- */

drop hhnr
drop persnr
drop gebjahr-znetto
drop zpop-baphrf

/* -----------------------( Rename some variables )----------------------- */

rename d1110109 age
rename d1110509 relation
rename d1110609 personshh
rename h1110109 childhh
rename siops09 siops
rename isced09 isced
rename i1110210 hhincome
rename bap12001 donate
rename bap12002 amount


/* --------------------------( Decode missing values  )-------------------------- */

mvdecode age sex siops isced donate amount, mv (-2=.\-1=.)


/* --------( Create variables for donating behavior on household level )--------- */

* 	a, Recode donating variable (yes/no)
	recode donate (2=0)
* 	b, Set household to donor household if at least one member was a donor
	by zhhnr, sort: egen hhdonate = max(donate) if zhhnr<.
*	c, Determine the relative monetary amounts of the donations (for donor households)
	by zhhnr, sort: egen hhamount = total(amount) if zhhnr<., missing
	by zhhnr: replace hhamount = hhamount[_N]
	generate hhrelative = ((hhamount * 100) / hhincome)
*	d, Determine the relative monetary amounts of the donations (for all households)
	generate hhrelativeA = hhrelative
	replace hhrelativeA = 0 if hhdonate==0

	
/* ----------------( Create social class measure on household level )------------- */

* 1. Weighted annual after-tax hh-income	
*	a, generate OECD equivalence weight
	generate oecd = (1 + 0.7 * (personshh - childhh - 1) + 0.5 * childhh)
* 	b, divide income by OECD weight
	generate wincome = round(hhincome/oecd)
* 	c, recode weighted income measure into a categorical income measure similar to Piff et al. (2010)
	sum oecd if relation==1
	recode wincome (0/6000 = 1) (6001/10000 = 2) (10001/14000 = 3) (14001/20000 = 4) ///
	(20001/30000 = 5) (30001/40000 = 6) (40001/60000 = 7) (60001/max = 8) if wincome<.
	hist wincome

* 2. Drop all persons that are not the household head
*	  -> 	thereby, education and occupational prestige of only the household head 
*			will be considered in the following calculations
*     -> but first determine the mean age of all household members
	sum age if hhdonate<.
	drop if relation~=1

* 5. Now standardize the indicators of obj. social class
	center wincome if wincome<., standardize
	center isced if isced<., standardize 
	center siops if siops<., standardize 
	
* 6. Generate the composite measure etc.
	egen hhclass = rowmean(c_wincome c_isced c_siops)
	center hhclass, standardize
	generate qc_hhclass = c_hhclass^2	
	
/* ----------------( Prepare data for the figures (that are drawn in R) )----------------- */

xtile dclass = c_hhclass, n(10)
drop if hhdonate==.
drop if c_hhclass==.
egen ddonate = mean(hhdonate), by(dclass)
egen drelative = mean(hhrelative), by(dclass)
egen drelativeA = mean(hhrelativeA), by(dclass)


/* --------------( Delete variables that are not needed for final analyses )--------------- */

keep personshh wincome hhdonate hhrelative hhrelativeA c_hhclass qc_hhclass ///
dclass-drelativeA c_wincome isced siops c_isced c_siops

label variable hhdonate "donor household (0=no; 1=yes)"
label variable hhrelative "relative monetary amounts of the donations of donor households"
label variable hhrelativeA "relative monetary amounts of the donations of all households"
label variable wincome "income category"
label variable isced "isced category of the household head"
label variable siops "siops category of the household head"
label variable c_hhclass "standardized objective social class"
label variable qc_hhclass "squared standardized objective social class"
label variable dclass "decile of objective social class"
label variable ddonate "proportion of donating households per decile of objective social class"
label variable drelative "relative monetary amounts of the donations of donor households per decile of objective social class"
label variable drelativeA "relative monetary amounts of the donations of all households per decile of objective social class"


/* --------------( save file for (re)analyses )--------------- */

saveold  "${MY_OUT_FILE}", replace


log close
