setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study2 <- read.dta('Study2.dta')

# Convert into csv-File
write.csv(study2, "C:/Users/User/Desktop/Study 2/Study2.csv", row.names=TRUE)

# possibly create Figure2 that contains all 6 panels
postscript(file="Figure2.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(3,3))


########## Figure 2A ##########
attach(study2)
order <- order(dssoclass)
order.class <- dssoclass[order]
ddonlog100 <- ddonlog*100
order.donlog <- ddonlog100[order]
plot(order.class, order.donlog,
main="Proportion of donating households\n(per decile of obj. soc. class)", 
xlab="Decile of obj. social class", ylab="Percent", 
mgp=c(2.65,1,0),
xaxs="i",
xlim = c(0.5, 10), 
ylim = c(0, 100), type = "l", lwd=1, bty="l", yaxs="i", xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("A",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )
points(order.class, order.donlog, cex=0.7, pch=20)
detach(study2)

########## Figure 2B ##########
library(locfit)
ttt <- locfit(donlog~ssoclass, family="binomial", data=study2, alpha=1)
loclog<-predict(ttt, data.frame(ssoclass = seq(-2.41, 2.21, 0.01)))
loclog100 <- loclog*100
plot(seq(-2.41,2.21,0.01), loclog100, main="Probability of donating\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percent", 
xlim = c(-3, 3), 
mgp=c(2.65,1,0),
ylim = c(0, 100),
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("B",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )

########## Figure 2C #########
x <- seq(-2.41,2.21,0.01)
y <- 1/(1+exp(-(-0.2210+0.6902*x-0.0575*x^2)))
y100 <- y*100
plot(x, y100, main="Predicted values\nof the probability of donating", 
     xlab="Standardized obj. social class", ylab="Percent", 
     xlim = c(-3, 3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 100),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("C",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )

########## Figure 2D #########
attach(study2)
order <- order(dssoclass)
order.class <- dssoclass[order]
order.dondon <- ddondon[order]
order.donall <- ddonall[order]
plot(order.class, order.dondon,
main="Relative amount of donations\n(means per decile of obj. soc. class)", 
xlab="Decile of obj. social class", ylab="Percentage of\ncontributed household income", 
mgp=c(2.3,1,0),
xaxs="i",
xlim = c(0.5, 10), 
ylim = c(0, 2.5), type = "l", lty=2, lwd=1, bty="l", yaxs="i", xaxp=c(1,10,9), yaxp=c(0,2.5,5), cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("D",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )
lines(order.class, order.donall,
type = "l", lwd=1, lty=1)
points(order.class, order.dondon, cex=0.7, pch=20)
points(order.class, order.donall, cex=0.7, pch=20)
legend (1.5, 2.45, c("donating households", "all households"), lty=c(2,1))
detach(study2)

########## Figure 2E ###############
lodondon <- with(study2, loess(dondon ~ ssoclass, span=0.8, degree=1))
prdondon <- predict(lodondon, data.frame(ssoclass = seq(-2.41, 2.21, 0.01)))
lodonall <- with(study2, loess(donall ~ ssoclass, span=0.8, degree=1))
prdonall <- predict(lodonall, data.frame(ssoclass = seq(-2.41, 2.21, 0.01)))
plot(seq(-2.41, 2.21, 0.01),prdondon, 
main="Relative amount of donations\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percentage of\ncontributed household income", 
mgp=c(2.3,1,0),
xlim = c(-3, 3), 
ylim = c(0, 2.5), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", yaxp=c(0,2.5,5), lty=2, cex.lab = 1, cex.axis = 1, cex.main=1)
lines(seq(-2.41, 2.21, 0.01),prdonall,
type = "l", lwd=1, lty=1)
legend (-2.5, 2.45, c("donating households", "all households"), lty=c(2,1))
mtext("E",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )

########## Figure 2F ###############
xdon <- seq(-2.41,2.21,0.01)
ydon <- 0.8295-0.2275*xdon+0.1350*xdon^2
xall <- seq(-2.41,2.21,0.01)
yall <- 0.3690+0.0777*xall+0.0195*xall^2

plot(xdon,ydon, 
     main="Predicted values\nof the relative amount of donations", 
     xlab="Standardized obj. social class", ylab="Percentage of\ncontributed household income", 
     mgp=c(2.3,1,0),
     xlim = c(-3, 3), 
     ylim = c(0, 2.5), 
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", yaxp=c(0,2.5,5), lty=2, cex.lab = 1, cex.axis = 1, cex.main=1)
lines(xall,yall,
      type = "l", lwd=1, lty=1)
legend (-2.5, 2.45, c("donating households", "all households"), lty=c(2,1))
mtext("F",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )



dev.off()