
/* -----   Here you can customize the paths and options:   ----- */

global MY_IN_PATH   = "path/to/the/directory/you/have/been/saving/the/cex/folders"                                                             
global MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"                                                                             
global MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"

global MY_OUT_FILE  ${MY_OUT_PATH}Study2.dta
global MY_LOG_FILE  ${MY_OUT_PATH}Study2_data_preparation.log

log using "${MY_LOG_FILE}", text replace

set more off


********************************************************************************
* The CEX data can be downloaded from http://www.bls.gov/cex/pumdhome.htm*******
********************************************************************************
* For our analyses, we used data from 2005 to 2012 (downloaded on 13-Nov-2013) *
* According to the file, the 2012 data has been last amended on 29-Aug-2013 ****
********************************************************************************



* -------------------------- treat cnt-files -------------------------*

/* -----------------[ cnt 2012 ]----------------- */

use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2012\EXPN\cnt12.dta"
keep if contcode=="160" 
gen cnt_year = 2012
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt12.dta", replace
clear

/* ------------------[ cnt 11 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2011\EXPN\cnt11.dta"
keep if contcode=="160"
gen cnt_year = 2011
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt11.dta", replace
clear

/* ------------------[ cnt 10 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2010\EXPN\cnt10.dta"
keep if contcode=="160"
gen cnt_year = 2010
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt10.dta", replace
clear

/* ------------------[ cnt 09 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2009\EXPN\cnt09.dta"
keep if contcode=="160"
gen cnt_year = 2009
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt09.dta", replace
clear

/* ------------------[ cnt 08 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2008\EXPN\cnt08.dta"
keep if contcode=="160"
gen cnt_year = 2008
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt08.dta", replace
clear

/* ------------------[ cnt 07 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2007\EXPN\cnt07.dta"
keep if contcode=="160"
gen cnt_year = 2007
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt07.dta", replace
clear

/* ------------------[ cnt 06 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2006\EXPN\cnt06.dta"
keep if contcode=="160"
gen cnt_year = 2006
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt06.dta", replace
clear

/* ------------------[ cnt 05 ] ----------------*/
use    	newid qyear contcode contmo contexpx ///
using  "${MY_IN_PATH}\2005\EXPN\cnt05.dta"
keep if contcode=="160"
gen cnt_year = 2005
replace contexpx = contexpx*3 if contmo=="13"
bysort newid: egen donat = total(contexpx)
by newid, sort: drop if _n~=1
save  "${MY_TEMP_PATH}cnt05.dta", replace
clear

* -------------------- Now append the cnt-files to one file ---------------------*

use "${MY_TEMP_PATH}cnt12.dta", clear
append using "${MY_TEMP_PATH}cnt11.dta"
append using "${MY_TEMP_PATH}cnt10.dta"
append using "${MY_TEMP_PATH}cnt09.dta"
append using "${MY_TEMP_PATH}cnt08.dta"
append using "${MY_TEMP_PATH}cnt07.dta"
append using "${MY_TEMP_PATH}cnt06.dta"
append using "${MY_TEMP_PATH}cnt05.dta"

save  "${MY_TEMP_PATH}cnt_master.dta", replace

foreach X of numlist 12 11 10 {
erase "${MY_TEMP_PATH}cnt`X'.dta"
}
foreach X of numlist 9 8 7 6 5 {
erase "${MY_TEMP_PATH}cnt0`X'.dta"
}

* ATTENTION: Install package nsplit before next command
nsplit newid, digits(6 1) generate(id int_nr)

* Check for duplicates that arise from the fmli121x and fmli121 files
duplicates report newid donat
duplicates drop newid, force

* Sum donations that were given in consecutive years
* e.g. a CU may donate money in December 2010 and in June 2011
* yet, by now, these CU donations are not summed up
sort id int_nr
by id, sort: egen donation = total(donat)

* Drop duplicated ids (because now donations are summed up)
duplicates report id
duplicates drop id, force

* Save condensed cnt-file
sort  id
save "${MY_TEMP_PATH}cnt.dta", replace


* ---------------------------------- treat fmli-files ----------------*

/* -----------------[ fmli131]----------------- */
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}2012\Interview\fmli131.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli131.dta", replace
clear

foreach X of numlist 12 11 10 {
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\20`X'\Interview\fmli`X'4.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli`X'4.dta", replace
clear

use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\20`X'\Interview\fmli`X'3.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli`X'3.dta", replace
clear

use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\20`X'\Interview\fmli`X'2.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli`X'2.dta", replace
clear

/* -----------------[ fmli121x]_> take 121-file from 2012 CEX-data----------------- */
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\20`X'\Interview\fmli`X'1x.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli`X'1.dta", replace
clear
}


foreach X of numlist 9 8 7 6{
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\200`X'\Interview\fmli0`X'4.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli0`X'4.dta", replace
clear

use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\200`X'\Interview\fmli0`X'3.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli0`X'3.dta", replace
clear

use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\200`X'\Interview\fmli0`X'2.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli0`X'2.dta", replace
clear

use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\200`X'\Interview\fmli0`X'1x.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli0`X'1.dta", replace
clear
}


/* -----------------[ fmli054]----------------- */
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\2005\Interview\fmli054.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli054.dta", replace
clear

/* -----------------[ fmli053]----------------- */
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\2005\Interview\fmli053.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli053.dta", replace
clear

/* -----------------[ fmli052]----------------- */
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\2005\Interview\fmli052.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli052.dta", replace
clear

/* -----------------[ fmli051x]_> take 051-file from 2005 CEX-data----------------- */
use newid fincatxm qintrvmo qintrvyr fam_size as_comp1 ///
		as_comp2 as_comp3 as_comp4 as_comp5 age_ref ///
		educ_ref earncomp respstat ///
using  "${MY_IN_PATH}\2005\Interview\fmli051x.dta"
sort  newid
save  "${MY_TEMP_PATH}fmli051.dta", replace
clear

* -------------------- Now append them to one file ---------------------*

use "${MY_TEMP_PATH}fmli131.dta", clear
sort  newid
append using "${MY_TEMP_PATH}fmli124.dta"
append using "${MY_TEMP_PATH}fmli123.dta"
append using "${MY_TEMP_PATH}fmli122.dta"
append using "${MY_TEMP_PATH}fmli121.dta"
append using "${MY_TEMP_PATH}fmli114.dta"
append using "${MY_TEMP_PATH}fmli113.dta"
append using "${MY_TEMP_PATH}fmli112.dta"
append using "${MY_TEMP_PATH}fmli111.dta"
append using "${MY_TEMP_PATH}fmli104.dta"
append using "${MY_TEMP_PATH}fmli103.dta"
append using "${MY_TEMP_PATH}fmli102.dta"
append using "${MY_TEMP_PATH}fmli101.dta"
append using "${MY_TEMP_PATH}fmli094.dta"
append using "${MY_TEMP_PATH}fmli093.dta"
append using "${MY_TEMP_PATH}fmli092.dta"
append using "${MY_TEMP_PATH}fmli091.dta"
append using "${MY_TEMP_PATH}fmli084.dta"
append using "${MY_TEMP_PATH}fmli083.dta"
append using "${MY_TEMP_PATH}fmli082.dta"
append using "${MY_TEMP_PATH}fmli081.dta"
append using "${MY_TEMP_PATH}fmli074.dta"
append using "${MY_TEMP_PATH}fmli073.dta"
append using "${MY_TEMP_PATH}fmli072.dta"
append using "${MY_TEMP_PATH}fmli071.dta"
append using "${MY_TEMP_PATH}fmli064.dta"
append using "${MY_TEMP_PATH}fmli063.dta"
append using "${MY_TEMP_PATH}fmli062.dta"
append using "${MY_TEMP_PATH}fmli061.dta"
append using "${MY_TEMP_PATH}fmli054.dta"
append using "${MY_TEMP_PATH}fmli053.dta"
append using "${MY_TEMP_PATH}fmli052.dta"
append using "${MY_TEMP_PATH}fmli051.dta"

duplicates list newid

save  "${MY_TEMP_PATH}fmli_master.dta", replace

erase "${MY_TEMP_PATH}fmli131.dta"
foreach X of numlist 12 11 10 {
erase "${MY_TEMP_PATH}fmli`X'4.dta"
erase "${MY_TEMP_PATH}fmli`X'3.dta"
erase "${MY_TEMP_PATH}fmli`X'2.dta"
erase "${MY_TEMP_PATH}fmli`X'1.dta"
}
foreach X of numlist 9 8 7 6 5 {
erase "${MY_TEMP_PATH}fmli0`X'4.dta"
erase "${MY_TEMP_PATH}fmli0`X'3.dta"
erase "${MY_TEMP_PATH}fmli0`X'2.dta"
erase "${MY_TEMP_PATH}fmli0`X'1.dta"
}


*********************** Now condense the fmli-master file **************

sort newid
nsplit newid, digits(6 1) generate(id int_nr)

* drop those CU that weren`t interviewed four times
by id, sort: gen intcount = _N
drop if intcount~=4
drop intcount

* drop respondents with incomplete income response
tab respstat
drop if respstat=="2" & int_nr==5

* set education to missing for those reference persons that gave inconsistent information...
* on highest education within the four interviews, 
encode educ_ref, gen(education)
recode education (00=1) (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9), gen(oeduc)
tab oeduc
* mean education of all four interviews
by id, sort: egen meduc = mean(oeduc)
tab meduc
* maximum education of all four interviews
by id, sort: egen meduc2 = max(oeduc)
tab meduc2
* -> set those to missing where mean education is not equal to the maximum education
gen educ_c = 1
replace educ_c =0 if meduc~=meduc2
replace meduc =. if educ_c == 0

* drop first three interviews
drop if int_nr~=5
duplicates list id

* calculate household weights based on OECD household weights
* OECD: set each single adult to 1.0
*       set each additional adult to 0.7
*		set each child to 0.5
egen adults = rowtotal(as_comp1 as_comp2)
egen childs = rowtotal(as_comp3 as_comp4 as_comp5)
list as_comp1 as_comp2 adults in 1/30
list as_comp3 as_comp4 as_comp5 childs in 1/30
gen oecd = (1 + 0.7*(adults-1) + 0.5*childs)
sum oecd

* compute the weighted after tax household income
hist fincatxm
sum fincatxm
* delete negative incomes
drop if fincatxm<0
sum fincatxm
gen wfincatxm = fincatxm/oecd
hist wfincatxm
* income categories similar to Piff et al. (2010)
	* original income categories: (0/15000=1) (15001/25000=2) (25001/35000=3) (35001/50000=4) (50001/75000=5) 
	* (75001/100000=6) (100001/150000=7) (150001/max=8)
	* categories should be adjusted to the oecd-weights as well (mean oecd-weight = 1.968)
recode wfincatxm (0/7500=1) (7501/12500=2) (12501/17500=3) (17501/25000=4) (25000.5/37500=5) ///
    (37501/50000=6) (50001/75000=7) (75001/max=8) (min/-1=.), gen(cincome)
hist cincome

* standardize income value
egen scincome = std(cincome)

* standardize education of the CU reference person (= second indicator of social class)
egen soeduc = std(meduc)

* generate the social class measure of income AND education 
egen soclass = rowmean(scincome soeduc)
egen ssoclass = std(soclass)
gen qssoclass = ssoclass^2

* check for duplicates again
duplicates report newid
duplicates report id 

* Save condensed fmli-file
sort id
save "${MY_TEMP_PATH}fmli.dta", replace
clear


* ----------------- Now merge cnt and fmli file together -------------*

use "${MY_TEMP_PATH}fmli.dta", clear
merge id using "${MY_TEMP_PATH}cnt.dta"

* drop CUs that weren't interviewed four times, that didn't give full information
* on their income etc.
drop if _merge==2


* ---------------- Prepare for calculations ------------------------------*

* generate variable that indicates whether or not CU is a donor-CU
gen donlog = 1 if _merge==3
replace donlog = 0 if _merge==1
drop   _merge

* generate variable that indicates how much donor-CUs donated
sum donation if donlog==0
sum donation if donlog==1
generate dondon = ((donation * 100) / fincatxm)

* drop CUs that made implausible high donations
drop if dondon>100 & dondon<.

* generate variable that indicates how much each CU donated
generate donall = ((donation * 100) / fincatxm)
replace donall = 0 if donlog==0


*------------------------------ Calculate Deciles, donor CUs per decile etc. ---------------------------*
xtile dssoclass = ssoclass, n(10)
egen ddonlog = mean(donlog), by(dssoclass)
egen ddondon = mean(dondon), by(dssoclass)
egen ddonall =mean(donall), by(dssoclass)


/* --------------( Delete variables that are not needed for final analyses )--------------- */

keep fam_size cincome meduc ssoclass qssoclass dssoclass donlog ddonlog dondon ddondon donall ddonall ///
scincome soeduc

label variable fam_size	"persons per household"
label variable meduc "educational category of the reference person"
label variable cincome "income category"
label variable ssoclass	"standardized objective social class"
label variable qssoclass "squared standardized objective social class"
label variable donlog "donor household	(0=no; 1=yes)"
label variable dondon "relative monetary amounts of the donations of donor households"
label variable donall "relative monetary amounts of the donations of all households"
label variable dssoclass "decile of objective social class"
label variable ddonlog "proportion of donating households per decile of objective social class"
label variable ddondon "relative monetary amounts of the donations of donor households per decile of objective social class"
label variable ddonall "relative monetary amounts of the donations of all households per decile of objective social class"


/* --------------------------( done! )-------------------------- */

label data " CEX - Ready to start!!!!!!! "
saveold  "${MY_OUT_FILE}", replace
desc

log close
