setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study3 <- read.dta('Study3.dta')

# Convert into csv-File
write.csv(study3, "C:/Users/User/Desktop/Study 3/Study3.csv", row.names=TRUE)

# possibly create Figure3 that contains all 4 panels
postscript(file="Figure3.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(2,2))

##### Figure 3A ########
attach(study3)
order <- order(dobject)
order.object <- dobject[order]
objdgive100 <- objdgive*100
order.objdgive <- objdgive100[order]
plot(order.object, order.objdgive,
main="Proportion of donors\n(per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Percent", 
xaxs="i",
mgp=c(2.65,1,0),
xlim = c(0.5, 10), 
ylim = c(0, 100), type = "l", lwd=1, bty="l", yaxs="i", xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("A",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
points(order.object, order.objdgive, cex=0.7, pch=20)
detach(study3)

##### Figure 3B ########
library(locfit)
lodgivchrty <- locfit(dgivchrty~c_object, family="binomial", data=study3, alpha=1)
pdgivchrty<-predict(lodgivchrty, data.frame(c_object = seq(-2.49, 2.69, 0.01)))
pdgivchrty100 <- pdgivchrty*100
plot(seq(-2.49, 2.69,0.01), pdgivchrty100, main="Probability of donating\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percent", 
mgp=c(2.65,1,0),
xlim = c(-3, 3.0),
ylim = c(0, 100), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("B",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )

##### Figure 3C ########
attach(study3)
order <- order(subject)
order.subject <- subject[order]
subjdgive100 <- subjdgive*100
order.subjdgive <- subjdgive100[order]
plot(order.subject, order.subjdgive,
     main="Proportion of donors\n(per category of subj. soc. class)", 
     xlab="Subj. social class", ylab="Percent",
     xaxt="n", xaxp=c(1,4,3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 100), type = "l", lwd=1, lty=1, bty="l", yaxs="i", cex.lab = 1, cex.axis = 1, cex.main=1.1)
axis(1, 1:4, labels=c("Lower\nclass", "Working\nclass", "Middle\nclass", "Upper\nclass"), mgp=c(2.65,1.5,0), cex.axis=1.0)
points(order.subject, order.subjdgive,cex=0.7, pch=20)
mtext("C",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
detach(study3)

##### Figure 3D ########
x <- seq(-2.49,2.69,0.01)
# determine "average year" for intercept
1.60235+((.0639-.4374)/3)
ylogobj <- 1/(1+exp(-(1.4779+0.9332*x-0.0462*x^2)))
ylogobj100 <- ylogobj*100

xsub <- seq(-2.21,2.32,0.01)
# determine "average year" for intercept
1.5141+((.0714-.4116)/3)
ylogsubj <- 1/(1+exp(-(1.4007+0.4744*xsub-0.1026*xsub^2)))
ylogsubj100 <- ylogsubj*100

plot(x,ylogobj100,
    main="Predicted values\nof the probability of donating", 
    xlab="Standardized social class", ylab="Percent", 
    mgp=c(2.65,1,0),
    xlim = c(-3, 3),
    ylim = c(0, 100), 
    type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
    mtext("D",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
lines(xsub,ylogsubj100,
    type = "l", lwd=1, lty=2)     
legend (-1, 40, c("subj. social class", "obj. social class"), lty=c(2,1))


dev.off()