setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study3 <- read.dta('Study3.dta')

# possibly create Figure4 that contains all 4 panels
postscript(file="Figure4.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(2,2))


##### Figure 4A ########
attach(study3)
order <- order(dobject)
order.object <- dobject[order]
order.objgive <- objgive[order]
plot(order.object, order.objgive,
     main="Frequency of donating\n(per decile of obj. soc. class)", 
     xlab="Deciles of obj. social class", ylab="Frequency (category)", 
     xaxs="i",
     mgp=c(2.65,1,0),
     xlim = c(0.5, 10), yaxp=c(0,3,6),
     ylim = c(0, 3), type = "l", lwd=1, bty="l", yaxs="i", xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("A",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
points(order.object, order.objgive,cex=0.7, pch=20)
detach(study3)

##### Figure 4B ########
logivchrty <- with(study3, loess(givchrty ~ c_object, span=0.8, degree=1))
pgivchrty <- predict(logivchrty, data.frame(c_object = seq(-2.49, 2.69, 0.01)))
plot(seq(-2.49, 2.69,0.01), pgivchrty, main="Frequency of donating\n(locally regressed on obj. soc. class)", 
     xlab="Standardized obj. social class", ylab="Frequency (category)", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(0, 3), yaxp=c(0,3,6),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("B",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )

##### Figure 4C ########
attach(study3)
order <- order(subject)
order.subject <- subject[order]
order.subjgive <- subjgive[order]
plot(order.subject, order.subjgive,
     main="Frequency of donating\n(per category of subj. soc. class)", 
     xlab="Subj. social class", ylab="Frequency (category)",
     xaxt="n", xaxp=c(1,4,3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 3), yaxp=c(0,3,6),
     type = "l", lwd=1, bty="l", yaxs="i", cex.lab = 1, cex.axis = 1, cex.main=1.1)
axis(1, 1:4, labels=c("Lower\nclass", "Working\nclass", "Middle\nclass", "Upper\nclass"), mgp=c(2.65,1.5,0), cex.axis=1.0)
mtext("C",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
points(order.subject, order.subjgive,cex=0.1, pch=20)
detach(study3)

##### Figure 4D ########
x <- seq(-2.49,2.69,0.01)
# determine "average year" for intercept
1.9022+((.0638-.1995)/3)
yordobj <- 1.8570+0.4465*x-0.0578*x^2

xsub <- seq(-2.21,2.32,0.01)
# determine "average year" for intercept
1.8856+((.0646-.0382)/3)
yordsubj <- 1.8944+0.2736*xsub-0.0382*xsub^2

plot(x,yordobj,
     main="Predicted values\nof the frequency of donating", 
     xlab="Standardized social class", ylab="Frequency (category)", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(0, 3), yaxp=c(0,3,6),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("D",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
lines(xsub,yordsubj,
      type = "l", lwd=1, lty=2)     
legend (-1, 1, c("subj. social class", "obj. social class"), lty=c(2,1))


dev.off()