clear all

cd "path/to/the/directory/for/the/resulting/file/"

log using Study3_analysis, text replace

use Study3, clear


/* ----------------( Descriptive analysis of the sample )----------------- */

pwcorr c_subject c_object if missing(givchrty, c_object, age, sex, year)==0, obs sig
tab sex if missing(givchrty, c_object, age, sex, year)==0
sum age if missing(givchrty, c_object, age, sex, year)==0
sum income98 if missing(givchrty, c_object, age, sex, year)==0 & year~=2012
sum income06 if missing(givchrty, c_object, age, sex, year)==0 & year==2012
sum siops if missing(givchrty, c_object, age, sex, year)==0
sum degree if missing(givchrty, c_object, age, sex, year)==0
tab givchrty if missing(givchrty, c_object, age, sex, year)==0
sum subject if missing(givchrty, subject, age, sex, year)==0

sum c_object if missing(givchrty, c_object, age, sex, year)==0
sum c_subject if missing(givchrty, c_subject, age, sex, year)==0

/* --------------( Analysis of social class' effects on donating )--------------- */

* 1. Probability of donating
* 	a) objective social class
	logistic dgivchrty c_object qc_object age sex i.year
	logistic dgivchrty c_object qc_object i.year if missing(age,sex)==0
* 	b) subjective social class
	logistic dgivchrty c_subject qc_subject age sex i.year
	logistic dgivchrty c_subject qc_subject i.year if missing(age,sex)==0

* 2. Frequency of donating
* 	a) objective social class
	oprobit givchrty c_object qc_object age sex i.year
	regress givchrty c_object qc_object age sex i.year
	oprobit givchrty c_object qc_object i.year if missing(age,sex)==0
	regress givchrty c_object qc_object i.year if missing(age,sex)==0
* 	b) subjective social class
	oprobit givchrty c_subject qc_subject age sex i.year
	regress givchrty c_subject qc_subject age sex i.year
	oprobit givchrty c_subject qc_subject i.year if missing(age,sex)==0
	regress givchrty c_subject qc_subject i.year if missing(age,sex)==0
	

/* --( Regressions to determine correct intercepts for the figures )-- */

recode sex (1=-1) (2=1), generate(sexnew)
center age if missing(givchrty, c_object, age, sex, year)==0
rename c_age age_obj
center age if missing(givchrty, c_subject, age, sex, year)==0
rename c_age age_subj
sum age*

logit dgivchrty c_object qc_object age_obj sexnew i.year	
logit dgivchrty c_subject qc_subject age_subj sexnew i.year	

regress givchrty c_object qc_object age_obj sexnew i.year
regress givchrty c_subject qc_subject age_subj sexnew i.year
	
/* --( Supplementary analysis of the effects of indicators of social class )-- */

generate qc_income = c_income^2
generate qc_degree = c_degree^2
generate qc_siops = c_siops^2

* 1. Probability of donating
	logistic dgivchrty c_income qc_income age sex i.year
	logistic dgivchrty c_income qc_income i.year if missing(age,sex)==0
	logistic dgivchrty c_degree qc_degree age sex i.year
	logistic dgivchrty c_degree qc_degree i.year if missing(age,sex)==0
	logistic dgivchrty c_siops qc_siops age sex i.year
	logistic dgivchrty c_siops qc_siops i.year if missing(age,sex)==0
	
* 2. Frequency of donating
	oprobit givchrty c_income qc_income age sex i.year
	regress givchrty c_income qc_income age sex i.year
	oprobit givchrty c_income qc_income i.year if missing(age,sex)==0
	regress givchrty c_income qc_income i.year if missing(age,sex)==0
	
	oprobit givchrty c_degree qc_degree age sex i.year
	regress givchrty c_degree qc_degree age sex i.year
	oprobit givchrty c_degree qc_degree i.year if missing(age,sex)==0
	regress givchrty c_degree qc_degree i.year if missing(age,sex)==0
	
	oprobit givchrty c_siops qc_siops age sex i.year
	regress givchrty c_siops qc_siops age sex i.year
	oprobit givchrty c_siops qc_siops i.year if missing(age,sex)==0
	regress givchrty c_siops qc_siops i.year if missing(age,sex)==0
	
	
log close
	