setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study4 <- read.dta('Study4.dta')

# Convert into csv-File
write.csv(study4, "C:/Users/User/Desktop/Study 4/Study4.csv", row.names=TRUE)

# possibly create Figure5 that contains all 6 panels
postscript(file="Figure5.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(3,3))

######### Figure A ##########
attach(study4)
order <- order(dclass)
order.class <- dclass[order]
dvolunteer100 <- d_dvolunteer*100
order.dvolunteer <- dvolunteer100[order]

plot(order.class,order.dvolunteer,
main="Proportion of volunteers\n(per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Percent", 
mgp=c(2.65,1,0),
xaxs="i",
xlim = c(0.5, 10), 
ylim = c(0, 60), type = "l", lwd=1, lty=1, yaxs="i", bty="l", xaxp=c(1,10,9), cex.lab = 1, cex.axis = 1, cex.main=1)
points(order.class,order.dvolunteer,cex=0.7, pch=20)
mtext("A",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )
detach(study4)


######## Figure B #############
library(locfit)
locvol <- locfit(dvolunteer~c_soclass, family="binomial", data=study4, alpha=1)
vol<-predict(locvol, data.frame(c_soclass = seq(-2.39, 3.50, 0.01)))
vol_100 <- vol*100

plot(seq(-2.39,3.50,0.01), vol_100, main="Probability of volunteering\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percent", 
mgp=c(2.65,1,0),
xlim = c(-3, 3),
ylim = c(0, 60), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("B",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )


######## Figure C #############
x <- seq(-2.39,3.50,0.01)
# determine "average year" for intercept
-1.7922+((-.1427-.2159+.1330)/4)
ylog <- 1/(1+exp(-(-1.8486+0.7096*x-0.0895*x^2)))
ylog100 <- ylog*100
plot(x, ylog100, main="Predicted values\nof the probability of volunteering", 
     xlab="Standardized obj. social class", ylab="Percent", 
     xlim = c(-3, 3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 60),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("C",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )


######### Figure D ##########
attach(study4)
order <- order(dclass)
order.class <- dclass[order]
order.volunteer <- d_volunteer[order]

plot(order.class,order.volunteer,
main="Frequency of volunteering\n(per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Frequency (category)", 
mgp=c(2.65,1,0),
xaxs="i",
xlim = c(0.5, 10), 
ylim = c(0, 1.5), type = "l", lwd=1, lty=1, yaxs="i", bty="l", xaxp=c(1,10,9), yaxp=c(0,2,4), cex.lab = 1, cex.axis = 1, cex.main=1)
points(order.class,order.volunteer,cex=0.7, pch=20)
mtext("D",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )
detach(study4)

######## Figure E #############
lovol <- with(study4, loess(volunteer ~ c_soclass, span=0.8, degree=1))
vol <- predict(lovol, data.frame(c_soclass = seq(-2.39, 3.50, 0.01)))

plot(seq(-2.39,3.50,0.01), vol, main="Frequency of volunteering\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Frequency (category)", 
mgp=c(2.65,1,0),
xlim = c(-3, 3),
ylim = c(0, 1.5), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, yaxp=c(0,2,4), cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("E",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )

######## Figure F #############
# determine "average year" for intercept
.6022+((-.0117-.0206+.0266)/4)
yglm <- 0.6008+0.1196*x-0.0104*x^2
plot(x, yglm, main="Predicted values\nof the frequency of volunteering", 
     xlab="Standardized obj. social class", ylab="Frequency (category)", 
     xlim = c(-3, 3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 1.5),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, yaxp=c(0,2,4), cex.lab = 1, cex.axis = 1, cex.main=1)
mtext("F",side=3, line = 1.5, adj=-0.12, cex=1.1, font=2 )



dev.off()