clear all

cd "path/to/the/directory/for/the/resulting/file/"

* Unfortunately, there was no approval of the SOEP to host the data
* on this server. Nevertheless, original data is available from the SOEP.

log using Study4_analysis, text replace

use Study4, clear


/* ----------------( Descriptive analysis of the sample )----------------- */

xtset persnr year

xttab sex if missing(volunteer, c_soclass, age, sex, year)==0
sum age if missing(volunteer, c_soclass, age, sex, year)==0
tab volunteer if missing(volunteer, c_soclass, age, sex, year)==0
tab dvolunteer if missing(volunteer, c_soclass, age, sex, year)==0

sum wincome if missing(volunteer, c_soclass, age, sex, year)==0
sum isced if missing(volunteer, c_soclass, age, sex, year)==0
sum siops if missing(volunteer, c_soclass, age, sex, year)==0

sum c_soclass if missing(volunteer, c_soclass, age, sex, year)==0


/* --------------( Analysis of social class' effects on volunteering )--------------- */

* 1. Analysis of the probability of volunteering
xtset, clear
melogit dvolunteer c_soclass qc_soclass age sex i.year ///
	if missing(dvolunteer, c_soclass, age, sex, year)==0|| persnr:, or
estat icc
melogit dvolunteer c_soclass qc_soclass i.year ///
	if missing(dvolunteer, c_soclass, age, sex, year)==0|| persnr:, or

* 2. Analysis of the frequency of volunteering
meoprobit volunteer c_soclass qc_soclass age sex i.year ///
	if missing(volunteer, c_soclass, age, sex, year)==0|| persnr:
mixed volunteer c_soclass qc_soclass age sex i.year ///
	if missing(volunteer, c_soclass, age, sex, year)==0|| persnr:

meoprobit volunteer c_soclass qc_soclass i.year ///
	if missing(volunteer, c_soclass, age, sex, year)==0|| persnr:
mixed volunteer c_soclass qc_soclass i.year ///
	if missing(volunteer, c_soclass, age, sex, year)==0|| persnr:

	
/* --( Regressions to determine correct intercepts for the figures )-- */

recode sex (1=-1) (2=1), generate(sexnew)
tab sexnew sex
center age if missing(volunteer, c_soclass, age, sex, year)==0

melogit dvolunteer c_soclass qc_soclass c_age sexnew i.year ///
	if missing(dvolunteer, c_soclass, age, sex, year)==0|| persnr:
mixed volunteer c_soclass qc_soclass c_age sexnew i.year ///
	if missing(volunteer, c_soclass, age, sex, year)==0|| persnr:
	
	
/* --( Supplementary analysis of the effects of indicators of social class )-- */

generate qc_wincome = c_wincome^2
generate qc_isced = c_isced^2
generate qc_siops = c_siops^2

* 1. Analysis of the probability of volunteering
melogit dvolunteer c_wincome qc_wincome age sex i.year ///
	if missing(dvolunteer, c_wincome, age, sex, year)==0|| persnr:, or
melogit dvolunteer c_wincome qc_wincome i.year ///
	if missing(dvolunteer, c_wincome, age, sex, year)==0|| persnr:, or
melogit dvolunteer c_isced qc_isced age sex i.year ///
	if missing(dvolunteer, c_isced, age, sex, year)==0|| persnr:, or
melogit dvolunteer c_isced qc_isced i.year ///
	if missing(dvolunteer, c_isced, age, sex, year)==0|| persnr:, or
melogit dvolunteer c_siops qc_siops age sex i.year ///
	if missing(dvolunteer, c_siops, age, sex, year)==0|| persnr:, or
melogit dvolunteer c_siops qc_siops i.year ///
	if missing(dvolunteer, c_siops, age, sex, year)==0|| persnr:, or

* 2. Analysis of the frequency of volunteering
meoprobit volunteer c_wincome qc_wincome age sex i.year ///
	if missing(volunteer, c_wincome, age, sex, year)==0|| persnr:
mixed volunteer c_wincome qc_wincome age sex i.year ///
	if missing(volunteer, c_wincome, age, sex, year)==0|| persnr:
meoprobit volunteer c_wincome qc_wincome i.year ///
	if missing(volunteer, c_wincome, age, sex, year)==0|| persnr:
mixed volunteer c_wincome qc_wincome i.year ///
	if missing(volunteer, c_wincome, age, sex, year)==0|| persnr:
	
meoprobit volunteer c_isced qc_isced age sex i.year ///
	if missing(volunteer, c_isced, age, sex, year)==0|| persnr:
mixed volunteer c_isced qc_isced age sex i.year ///
	if missing(volunteer, c_isced, age, sex, year)==0|| persnr:
meoprobit volunteer c_isced qc_isced i.year ///
	if missing(volunteer, c_isced, age, sex, year)==0|| persnr:
mixed volunteer c_isced qc_isced i.year ///
	if missing(volunteer, c_isced, age, sex, year)==0|| persnr:
	
meoprobit volunteer c_siops qc_siops age sex i.year ///
	if missing(volunteer, c_siops, age, sex, year)==0|| persnr:
mixed volunteer c_siops qc_siops age sex i.year ///
	if missing(volunteer, c_siops, age, sex, year)==0|| persnr:
meoprobit volunteer c_siops qc_siops i.year ///
	if missing(volunteer, c_siops, age, sex, year)==0|| persnr:
mixed volunteer c_siops qc_siops i.year ///
	if missing(volunteer, c_siops, age, sex, year)==0|| persnr:

	
log close
