/*                                                                       */
/* -----        How to customize the paths and options:   -----          */
/* -----        Some further explanations:                -----          */                                                                           
/*  The following                                                        */                              
/*                                                                       */                 
/*  global macros (in stata),                                            */                                          
/*                                                                       */                 
/*  define the locations for the original SOEP DATA, the directory       */                                                                               
/*  for temporary files and the destination of the resulting data file.  */                                                                                    
/*                                                                       */                 
/*  MY_IN_PATH   = "path/to/your/SOEP/directory/"                        */                                                              
/*  MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"       */                                                                               
/*  MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"      */                                                                                
/*                                                                       */                 
/*  The correct specification of the path depends on your Operating      */                                                                                
/*  System and on your SOEP installation, but be sure to use a           */                                                                           
/*  TRAILING backslash ("\", within Windows) or a                        */                                                              
/*  TRAILING forward slash ("/", within Unix/Linux).                     */                                                                 
/*                                                                       */                 
/*  You can also change the name for the resulting data file with the    */                                                                                  
/*  variable MY_OUT_FILE and the name for the log file (only with        */                                                                              
/*  stata, variable MY_LOG_FILE).                                        */                                              
/* ----------------------------------------------------------------      */                                                                                


/* -----   Here you can customize the paths and options:   ----- */

global MY_IN_PATH   = "path/to/your/SOEP/directory/"                                                             
global MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"                                                                             
global MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"

global MY_OUT_FILE  ${MY_OUT_PATH}\Study 4\Study4.dta
global MY_LOG_FILE  ${MY_OUT_PATH}\Study 4\Study4_data_preparation.log

log using "${MY_LOG_FILE}", text replace

set more off

***** To get access to the SOEP data, you have to conclude a data distribution contract with DIW Berlin ***
***** For more details, see http://www.diw.de/en/diw_02.c.222516.en/data.html *****************************
***********************************************************************************************************
***** For our analyses, we used data for years 1984-2012, Version 29, 2013 ********************************
***********************************************************************************************************


/* ----------------[ automatically pull PPFAD ]----------------- */

use    hhnr    persnr  sex  gebjahr psample ///
       bbhhnr bchhnr bahhnr  vhhnr   whhnr   zhhnr ///  
       bcnetto bbnetto banetto vnetto  wnetto  znetto /// 
       bcpop bbpop bapop   vpop    wpop    zpop ///
using  "${MY_IN_PATH}ppfad.dta"

/* --------------[ balanced / unbalanced design ]--------------- */

keep if ( ( banetto > 0 & banetto < 40 ) | ( vnetto > 0 & vnetto < 40 ) |   ///
          ( bcnetto > 0 & bcnetto < 40 ) | ( bbnetto > 0 & bbnetto < 40 ) |  ///
		  ( wnetto > 0 & wnetto < 40 ) | ( znetto > 0 & znetto < 40 ) )

/* -----------------[ private housholds only.]------------------ */

/* -- start comment
keep if ( ( bapop == 1 | bapop == 2 ) | ( tpop == 1 | tpop == 2 ) |
          ( upop == 1 | upop == 2 ) | ( vpop == 1 | vpop == 2 ) |
          ( wpop == 1 | wpop == 2 ) | ( zpop == 1 | zpop == 2 ) );
*/
/* -----------------------[ sort ppfad ]------------------------ */

sort persnr
save "${MY_TEMP_PATH}ppfad.dta", replace
clear

/* -----------------[ automatically pull PHRF ]----------------- */

use    hhnr    persnr  prgroup   ///
       bcphrf bbphrf baphrf  vphrf   wphrf   zphrf  ///
using  "${MY_IN_PATH}phrf.dta"

sort  persnr
save  "${MY_TEMP_PATH}phrf.dta", replace
clear

/* --------------[ automatically create pmaster ]--------------- */

use    "${MY_TEMP_PATH}ppfad.dta"
merge  persnr   ///
using  "${MY_TEMP_PATH}phrf.dta"

drop   if _merge == 2
drop   _merge
erase  "${MY_TEMP_PATH}ppfad.dta"
erase  "${MY_TEMP_PATH}phrf.dta"
sort   persnr
save   "${MY_TEMP_PATH}pmaster.dta", replace



/* -------------------------( pull vp )------------------------- */

use    hhnr    vhhnr   persnr    ///
       vp0307  ///
using "${MY_IN_PATH}vp.dta"

sort persnr
save "${MY_TEMP_PATH}vp.dta", replace
clear

/* -----------------------( pull vpgen )------------------------ */

use    hhnr    vhhnr   persnr     ///
       siops05 isced05   ///
using "${MY_IN_PATH}vpgen.dta"

sort persnr
save "${MY_TEMP_PATH}vpgen.dta", replace
clear

/* ----------------------( pull vpequiv )----------------------- */

use    hhnr    vhhnr   persnr     ///
       d1110105 d1110505 d1110605 h1110105   ///
using "${MY_IN_PATH}vpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}vpequiv.dta", replace
clear

/* ----------------------( pull wpequiv )----------------------- */

use    hhnr    whhnr   persnr     ///
       i1110206   ///
using "${MY_IN_PATH}wpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}wpequiv.dta", replace
clear

/* -------------------------( pull xp )------------------------- */

use    hhnr    xhhnr   persnr     ///
       xp0307   ///
using "${MY_IN_PATH}xp.dta"

sort persnr
save "${MY_TEMP_PATH}xp.dta", replace
clear

/* -----------------------( pull xpgen )------------------------ */

use    hhnr    xhhnr   persnr     ///
       siops07 isced07   ///
using "${MY_IN_PATH}xpgen.dta"

sort persnr
save "${MY_TEMP_PATH}xpgen.dta", replace
clear

/* ----------------------( pull xpequiv )----------------------- */

use    hhnr    xhhnr   persnr     ///
       d1110107 d1110507 d1110607 h1110107   ///
using "${MY_IN_PATH}xpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}xpequiv.dta", replace
clear

/* ----------------------( pull ypequiv )----------------------- */

use    hhnr    yhhnr   persnr     ///
       i1110208    ///
using "${MY_IN_PATH}ypequiv.dta"

sort persnr
save "${MY_TEMP_PATH}ypequiv.dta", replace
clear

/* ----------------------( pull zpequiv )----------------------- */

use    hhnr    zhhnr   persnr     ///
       d1110109 d1110509 d1110609 h1110109   ///
using "${MY_IN_PATH}zpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}zpequiv.dta", replace
clear

/* -------------------------( pull zp )------------------------- */

use    hhnr    zhhnr   persnr     ///
       zp0307   ///
using "${MY_IN_PATH}zp.dta"

sort persnr
save "${MY_TEMP_PATH}zp.dta", replace
clear

/* -----------------------( pull zpgen )------------------------ */

use    hhnr    zhhnr   persnr     ///
       siops09 isced09   ///
using "${MY_IN_PATH}zpgen.dta"

sort persnr
save "${MY_TEMP_PATH}zpgen.dta", replace
clear

/* ----------------------( pull bapequiv )---------------------- */

use    hhnr    bahhnr  persnr     ///
       i1110210   ///
using "${MY_IN_PATH}bapequiv.dta"

sort persnr
save "${MY_TEMP_PATH}bapequiv.dta", replace
clear


/* ----------------------( pull bbpequiv )----------------------- */

use    hhnr    bbhhnr   persnr     ///
       d1110111 d1110511 d1110611 h1110111   ///
using "${MY_IN_PATH}bbpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}bbpequiv.dta", replace
clear

/* -------------------------( pull bbp )------------------------- */

use    hhnr    bbhhnr   persnr     ///
       bbp0307   ///
using "${MY_IN_PATH}bbp.dta"

sort persnr
save "${MY_TEMP_PATH}bbp.dta", replace
clear

/* -----------------------( pull bbpgen )------------------------ */

use    hhnr    bbhhnr   persnr     ///
       siops11 isced11   ///
using "${MY_IN_PATH}bbpgen.dta"

sort persnr
save "${MY_TEMP_PATH}bbpgen.dta", replace
clear

/* ----------------------( pull bcpequiv )---------------------- */

use    hhnr    bchhnr  persnr     ///
       i1110212    ///
using "${MY_IN_PATH}bcpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}bcpequiv.dta", replace
clear



/* -----------------( Now merge all together )------------------ */

use   "${MY_TEMP_PATH}pmaster.dta"
erase "${MY_TEMP_PATH}pmaster.dta"

/* -----------( merge together by person: ALL Waves )----------- */


/* ------------------------( merge VP )------------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}vp.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}vp.dta"

/* -----------------------( merge VPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}vpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}vpgen.dta"

/* ----------------------( merge VPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}vpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}vpequiv.dta"

/* ----------------------( merge WPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}wpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}wpequiv.dta"

/* ------------------------( merge XP )------------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}xp.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}xp.dta"

/* -----------------------( merge XPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}xpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}xpgen.dta"

/* ----------------------( merge XPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}xpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}xpequiv.dta"

/* ----------------------( merge YPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}ypequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}ypequiv.dta"

/* ----------------------( merge ZPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}zpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}zpequiv.dta"

/* ------------------------( merge ZP )------------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}zp.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}zp.dta"

/* -----------------------( merge ZPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}zpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}zpgen.dta"

/* ---------------------( merge BAPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bapequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bapequiv.dta"


/* -----------------------( merge BBPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bbpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bbpgen.dta"

/* ---------------------( merge BBPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bbpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bbpequiv.dta"

/* ------------------------( merge BBP )------------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bbp.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bbp.dta"


/* ---------------------( merge BCPEQUIV )---------------------- */

         
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}bcpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}bcpequiv.dta"


/* --------------------------( Merging done! )-------------------------- */

label data "SOEPINFO: Magic at Work! http://panel.gsoep.de/soepinfo/"
save  "${MY_OUT_FILE}", replace
desc


/* --------------------------( Rename variables to tranform data-matrix into long-format  )-------------------------- */

soepren vhhnr whhnr xhhnr yhhnr zhhnr bahhnr bbhhnr bchhnr, ///
	newstub(hnr) waves(2005 2006 2007 2008 2009 2010 2011 2012)
soepren vpop wpop zpop bapop bbpop bcpop, ///
	newstub(pop) waves(2005 2006 2009 2010 2011 2012)
soepren vnetto wnetto znetto banetto bbnetto bcnetto, ///
	newstub(netto) waves(2005 2006 2009 2010 2011 2012)

soepren d1110105 d1110107 d1110109 d1110111, ///
	newstub(age) waves(2005 2007 2009 2011)
soepren d1110505 d1110507 d1110509 d1110511, ///
	newstub(relation) waves(2005 2007 2009 2011)
soepren d1110605 d1110607 d1110609 d1110611, ///
	newstub(personshh) waves(2005 2007 2009 2011)
soepren h1110105 h1110107 h1110109 h1110111, ///
	newstub(childhh) waves(2005 2007 2009 2011)

soepren isced05 isced07 isced09 isced11, ///
	newstub(isced) waves(2005 2007 2009 2011)
soepren siops05 siops07 siops09 siops11, ///
	newstub(siops) waves(2005 2007 2009 2011)
* Rename income variable 
* (and therby change the year of the assessment of income to the year income was actually earned)
soepren i1110206 i1110208 i1110210 i1110212, ///
	newstub(hhincome) waves(2005 2007 2009 2011)

soepren vp0307 xp0307 zp0307 bbp0307, newstub(volunteer) waves(2005 2007 2009 2011)

drop gebjahr
drop prgroup
drop vphrf-bcphrf

/* --------------------------( Reshape into long-format  )-------------------------- */

reshape long hnr netto pop age siops isced hhincome childhh personshh relation ///
	volunteer, i(persnr) j(year)
xtset persnr year


/* --------------------------( Decode missing values  )-------------------------- */

mvdecode age sex siops isced volunteer relation, mv (-2=.\-1=.)


/* --------------------------( Create measure of obj. social class  )-------------------------- */

* 1. standardize education and job prestige per year (but first set those "in school" to missing)
mvdecode isced, mv (0=.)
by year, sort: center isced siops, standardize

* 2. Weigthed annual after-tax hh-income
* 	a, generate OECD equivalence weight
	generate oecd = (1 + 0.7 * (personshh - childhh - 1) + 0.5 * childhh)
* 	b, divide income by OECD weight
	generate wincome = round(hhincome/oecd)
* 	c, recode weighted income measure into a categorical income measure similar to Piff et al. (2010)
	sum oecd if relation==1
	recode wincome (0/6000 = 1) (6001/10000 = 2) (10001/14000 = 3) (14001/20000 = 4) ///
	(20001/30000 = 5) (30001/40000 = 6) (40001/60000 = 7) (60001/max = 8) if wincome<.
	hist wincome
*  d, standardize this income measure
	by year, sort: center wincome, standardize

* 3. generate (and standize per year) composite measure of obj. social class
egen soclass = rowmean(c_wincome c_isced c_siops)
by year, sort: center soclass, standardize
* 4. calculate squared obj. social class measure
generate qc_soclass = c_soclass^2


/* --------------------------( Recode volunteer variable  )-------------------------- */

recode volunteer (4=0) (3=1) (2=2) (1=3)
recode volunteer (2=1) (3=1), prefix(d)


/* --------------------------( Prepare data for the figures (that are drawn in R)  )-------------------------- */

xtset, clear
xtile dclass = c_soclass, n(10)
keep if missing(volunteer, c_soclass, age, sex, year)==0
egen d_dvolunteer = mean(dvolunteer), by(dclass)
egen d_volunteer = mean(volunteer), by(dclass)


/* --------------( Anonymize the person number )--------------- */

bysort persnr: generate nnn = 1/_N
generate snnn = sum(nnn)
bysort persnr: replace persnr = snnn[_N]

drop nnn snnn


/* --------------( Delete variables that are not needed for final analyses )--------------- */

keep year persnr wincome isced siops age sex volunteer dvolunteer c_soclass qc_soclass dclass ///
dvolunteer-d_volunteer c_wincome c_isced c_siops

label variable persnr "anonymized person number"
label variable year	"year of measurement"
label variable sex	"respondent's sex"
label variable age	"age of respondent"
label variable wincome	"income category"
label variable isced "isced category of respondent (if not in school)"
label variable siops "siops category of respondent"
label variable c_soclass "standardized objective social class"
label variable qc_soclass "squared standardized objective social class"
label variable volunteer "how often did respondent volunteer? (0 = never; 3 = every week)"
label variable dvolunteer	"did respondent volunteer? (0=no; 1=yes)"
label variable dclass "decile of objective social class"
label variable d_dvolunteer "proportion of volunteers per decile of objective social class"
label variable d_volunteer "mean volunteering category per decile of objective social class"


/* --------------------------( save file for  (re)analyses  )-------------------------- */
saveold  "${MY_OUT_FILE}", replace


log close
