setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study5 <- read.dta('Study5.dta')

# Convert into csv-File
write.csv(study5, "C:/Users/User/Desktop/Study 5/Study5.csv", row.names=TRUE)

# possibly create Figure6 that contains all 4 panels
postscript(file="Figure6.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(2,2))

##### Figure 6A ########
attach(study5)
order <- order(dobject)
order.object <- dobject[order]
objdvol100 <- objdvol*100
order.objdvol <- objdvol100[order]
plot(order.object, order.objdvol,
main="Proportion of volunteers\n(per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Percent", 
xaxs="i",
mgp=c(2.65,1,0),
xlim = c(0.5, 10), yaxp=c(0,75,5),
ylim = c(0, 75), type = "l", lwd=1, bty="l", yaxs="i", xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("A",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
points(order.object, order.objdvol, cex=0.7, pch=20)
detach(study5)

##### Figure 6B ########
library(locfit)
lodvolchrty <- locfit(dvolchrty~c_object, family="binomial", data=study5, alpha=1)
pdvolchrty<-predict(lodvolchrty, data.frame(c_object = seq(-2.48, 2.69, 0.01)))
pdvolchrty100 <- pdvolchrty*100
plot(seq(-2.48, 2.69,0.01), pdvolchrty100, main="Probability of volunteering\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Percent", 
mgp=c(2.65,1,0),
xlim = c(-3, 3),
ylim = c(0, 75), yaxp=c(0,75,5),
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("B",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )


##### Figure 6C ########
attach(study5)
order <- order(subject)
order.subject <- subject[order]
subjdvol100 <- subjdvol*100
order.subjdvol <- subjdvol100[order]
plot(order.subject, order.subjdvol,
main="Proportion of volunteers\n(per category of subj. soc. class)", 
xlab="Subj. social class", ylab="Percent",
xaxt="n", xaxp=c(1,4,3), 
mgp=c(2.65,1,0),
ylim = c(0, 75), yaxp=c(0,75,5),
type = "l", lwd=1, bty="l", yaxs="i", cex.lab = 1, cex.axis = 1, cex.main=1.1)
axis(1, 1:4, labels=c("Lower\nclass", "Working\nclass", "Middle\nclass", "Upper\nclass"), mgp=c(2.65,1.5,0), cex.axis=1.0)
points(order.subject, order.subjdvol,cex=0.7, pch=20)
mtext("C",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
detach(study5)


##### Figure 6D ########
x <- seq(-2.49,2.69,0.01)
# determine "average year" for intercept
-.2552+((.2009+.0406)/3)
ylogobj <- 1/(1+exp(-(-.1747+0.4961*x+0.0152*x^2)))
ylogobj100 <- ylogobj*100

xsub <- seq(-2.21,2.32,0.01)
# determine "average year" for intercept
-.2330+((.1963+.0385)/3)
ylogsubj <- 1/(1+exp(-(-.1547+0.2517*xsub+0.0039*xsub^2)))
ylogsubj100 <- ylogsubj*100

plot(x,ylogobj100,
     main="Predicted values\nof the probability of volunteering", 
     xlab="Standardized social class", ylab="Percent", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(0, 75), yaxp=c(0,75,5),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("D",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
lines(xsub,ylogsubj100,
      type = "l", lwd=1, lty=2)     
legend (-1, 28, c("subj. social class", "obj. social class"), lty=c(2,1))


dev.off()
