setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study5 <- read.dta('Study5.dta')

# possibly create Figure7 that contains all 4 panels
postscript(file="Figure7.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(2,2))


##### Figure A ########
attach(study5)
order <- order(dobject)
order.object <- dobject[order]
order.objvol <- objvol[order]
plot(order.object, order.objvol,
     main="Frequency of volunteering\n(per decile of obj. soc. class)", 
     xlab="Deciles of obj. social class", ylab="Frequency (category)", 
     xaxs="i",
     mgp=c(2.65,1,0),
     xlim = c(0.5, 10), yaxp=c(0,3,6),
     ylim = c(0, 2.5), type = "l", lwd=1, bty="l", yaxs="i", xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("A",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
points(order.object, order.objvol,cex=0.7, pch=20)
detach(study5)

##### Figure B ########
lovolchrty <- with(study5, loess(volchrty ~ c_object, span=0.8, degree=1))
pvolchrty <- predict(lovolchrty, data.frame(c_object = seq(-2.48, 2.69, 0.01)))
plot(seq(-2.48, 2.69,0.01), pvolchrty, main="Frequency of volunteering\n(locally regressed on obj. soc. class)", 
     xlab="Standardized obj. social class", ylab="Frequency (category)", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(0, 2.5), yaxp=c(0,3,6),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("B",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )

##### Figure C ########
attach(study5)
order <- order(subject)
order.subject <- subject[order]
order.subjvol <- subjvol[order]
plot(order.subject, order.subjvol,
     main="Frequency of volunteering\n(per category of subj. soc. class)", 
     xlab="Subj. social class", ylab="Frequency (category)",
     xaxt="n", xaxp=c(1,4,3), 
     mgp=c(2.65,1,0),
     ylim = c(0, 2.5), yaxp=c(0,3,6),
     type = "l", lwd=1, bty="l", yaxs="i", cex.lab = 1, cex.axis = 1, cex.main=1.1)
axis(1, 1:4, labels=c("Lower\nclass", "Working\nclass", "Middle\nclass", "Upper\nclass"), mgp=c(2.65,1.5,0), cex.axis=1.0)
mtext("C",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
points(order.subject, order.subjvol,cex=0.7, pch=20)
detach(study5)


##### Figure D ########
x <- seq(-2.49,2.69,0.01)
# determine "average year" for intercept
1.0+((.1324+.0577)/3)
yordobj <- 1.0634+0.2914*x+0.0471*x^2

xsub <- seq(-2.21,2.32,0.01)
# determine "average year" for intercept
1.0323+((.1310+.0555)/3)
yordsubj <- 1.0945+0.1636*xsub+0.0201*xsub^2

plot(x,yordobj,
     main="Predicted values\nof the frequency of volunteering", 
     xlab="Standardized social class", ylab="Frequency (category)", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(0, 2.5), yaxp=c(0,3,6),
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("D",side=3, line = 2.2, adj=-0.12, cex=1.44, font=2 )
lines(xsub,yordsubj,
      type = "l", lwd=1, lty=2)     
legend (-0.5, 0.7, c("subj. social class", "obj. social class"), lty=c(2,1))

dev.off()