clear all

cd "path/to/the/directory/for/the/resulting/file/"

log using Study5_analysis, text replace

use Study5, clear


/* ----------------( Descriptive analysis of the sample )----------------- */

pwcorr c_subject c_object if missing(volchrty, c_object, age, sex, year)==0, obs sig
tab sex if missing(volchrty, c_object, age, sex, year)==0
sum age if missing(volchrty, c_object, age, sex, year)==0
sum income98 if missing(volchrty, c_object, age, sex, year)==0 & year~=2012
sum income06 if missing(volchrty, c_object, age, sex, year)==0 & year==2012
sum siops if missing(volchrty, c_object, age, sex, year)==0
sum degree if missing(volchrty, c_object, age, sex, year)==0
tab volchrty if missing(volchrty, c_object, age, sex, year)==0 // volchrty has been recoded!!
sum subject if missing(volchrty, subject, age, sex, year)==0

sum c_object if missing(volchrty, c_object, age, sex, year)==0
sum c_subject if missing(volchrty, c_subject, age, sex, year)==0

/* --------------( Analysis of social class' effects on volunteering )--------------- */

* 1. Probability of volunteering
* 	a) objective social class
	logistic dvolchrty c_object qc_object age sex i.year
	logistic dvolchrty c_object qc_object i.year if missing(age,sex)==0
* 	b) subjective social class
	logistic dvolchrty c_subject qc_subject age sex i.year
	logistic dvolchrty c_subject qc_subject i.year if missing(age,sex)==0

* 2. Frequency of volunteering
* 	a) objective social class
	oprobit volchrty c_object qc_object age sex i.year
	regress volchrty c_object qc_object age sex i.year
	oprobit volchrty c_object qc_object i.year if missing(age,sex)==0
	regress volchrty c_object qc_object i.year if missing(age,sex)==0
* 	b) subjective social class
	oprobit volchrty c_subject qc_subject age sex i.year
	regress volchrty c_subject qc_subject age sex i.year
	oprobit volchrty c_subject qc_subject i.year if missing(age,sex)==0
	regress volchrty c_subject qc_subject i.year if missing(age,sex)==0
	
	
/* --( Regressions to determine correct intercepts for the figures )-- */

recode sex (1=-1) (2=1), generate(sexnew)
center age if missing(volchrty, c_object, age, sex, year)==0
rename c_age age_obj
center age if missing(volchrty, c_subject, age, sex, year)==0
rename c_age age_subj
sum age*

logit dvolchrty c_object qc_object age_obj sexnew i.year	
logit dvolchrty c_subject qc_subject age_subj sexnew i.year	

regress volchrty c_object qc_object age_obj sexnew i.year
regress volchrty c_subject qc_subject age_subj sexnew i.year
	
		
/* --( Supplementary analysis of the effects of indicators of social class )-- */

generate qc_income = c_income^2
generate qc_degree = c_degree^2
generate qc_siops = c_siops^2

* 1. Probability of volunteering
	logistic dvolchrty c_income qc_income age sex i.year
	logistic dvolchrty c_income qc_income i.year if missing(age,sex)==0
	logistic dvolchrty c_degree qc_degree age sex i.year
	logistic dvolchrty c_degree qc_degree i.year if missing(age,sex)==0
	logistic dvolchrty c_siops qc_siops age sex i.year
	logistic dvolchrty c_siops qc_siops i.year if missing(age,sex)==0
	
* 2. Frequency of volunteering
	oprobit volchrty c_income qc_income age sex i.year
	regress volchrty c_income qc_income age sex i.year
	oprobit volchrty c_income qc_income i.year if missing(age,sex)==0
	regress volchrty c_income qc_income i.year if missing(age,sex)==0
	
	oprobit volchrty c_degree qc_degree age sex i.year
	regress volchrty c_degree qc_degree age sex i.year
	oprobit volchrty c_degree qc_degree i.year if missing(age,sex)==0	
	regress volchrty c_degree qc_degree i.year if missing(age,sex)==0	
	
	oprobit volchrty c_siops qc_siops age sex i.year
	regress volchrty c_siops qc_siops age sex i.year
	oprobit volchrty c_siops qc_siops i.year if missing(age,sex)==0	
	regress volchrty c_siops qc_siops i.year if missing(age,sex)==0	
	
	
log close
