clear all

cd "path/to/the/directory/for/the/resulting/file/"

log using Study6_analysis, text replace

use Study6, clear

/* ----------------( Descriptive analysis of the sample )----------------- */

tab sex if missing(vol, c_object, age, sex, v3)==0
sum age if missing(vol, c_object, age, sex, v3)==0
tab sex if missing(vol, subject, age, sex, v3)==0
sum age if missing(vol, subject, age, sex, v3)==0
sum siops if missing(vol, c_object, age, sex, v3)==0
sum degree if missing(vol, c_object, age, sex, v3)==0
sum subject if missing(vol, subject, age, sex, v3)==0
tab vol if missing(vol, c_object, age, sex, v3)==0

sum c_object if missing(vol, c_object, age, sex, v3)==0
sum c_subject if missing(vol, c_subject, age, sex, v3)==0

/* --------------( Analysis of social class' effects on volunteering )--------------- */

* 1. Probability of volunteering
*	a) objective social class
	xtmelogit dvol c_object qc_object age sex || v3: c_object qc_object, or
	estimates store qobject
	xtmelogit dvol c_object qc_object age sex || v3:, or
	estimates store noobject
	lrtest qobject noobject // test whether effect of obj. social class varies between countries
	xtmelogit dvol c_object qc_object if missing(dvol, c_object, age, sex, v3)==0 ///
		|| v3: c_object qc_object, or

	*	b) subjective social class
	xtmelogit dvol c_subject qc_subject age sex || v3: c_subject qc_subject, or
	estimates store qsubject
	xtmelogit dvol c_subject qc_subject age sex || v3:, or
	estimates store nosubject
	lrtest qsubject nosubject // test whether effect of subj. social class varies between countries
	xtmelogit dvol c_subject qc_subject if missing(dvol, subject, age, sex, v3)==0 ///
		|| v3: c_subject qc_subject, or
	
* 2. Frequency of volunteering
* To run the analyses faster and without errors, it is helpful to center all variables ...
* ... across the sample before starting the calculation.
* However, calculations still take a while

*	a) objective social class
	use Study6, clear
	keep if missing(vol,c_object,qc_object,age,sex,v3)==0
	center c_object qc_object age sex
	meoprobit vol c_c_object c_qc_object c_age c_sex ///
		|| v3: c_c_object c_qc_object, trace intmethod(mcaghermite)
	estimates store qobject
	meoprobit vol c_c_object c_qc_object c_age c_sex ///
		|| v3:, trace intmethod(mcaghermite)
	estimates store noobject
	lrtest qobject noobject // test whether effect of obj. social class varies between countries
	meoprobit vol c_c_object c_qc_object if missing(vol, c_object, age, sex, v3)==0 ///
		|| v3: c_c_object c_qc_object, trace intmethod(mcaghermite)
	
	mixed vol c_c_object c_qc_object c_age c_sex ///
		|| v3: c_c_object c_qc_object
	estimates store qobject_b
	mixed vol c_c_object c_qc_object c_age c_sex ///
		|| v3:
	estimates store noobject_b
	lrtest qobject_b noobject_b // test whether effect of obj. social class varies between countries
	mixed vol c_c_object c_qc_object if missing(vol, c_object, age, sex, v3)==0 ///
		|| v3: c_c_object c_qc_object

*	b) subjective social class
	use Study6, clear
	keep if missing(vol,c_subject,qc_subject,age,sex,v3)==0
	center c_subject qc_subject age sex	
	meoprobit vol c_c_subject c_qc_subject c_age c_sex ///
		|| v3: c_c_subject c_qc_subject, trace intmethod(mcaghermite)
	estimates store qsubject
	meoprobit vol c_c_subject c_qc_subject c_age c_sex ///
		|| v3:, trace intmethod(mcaghermite)
	estimates store nosubject
	lrtest qsubject nosubject // test whether effect of subj. social class varies between countries
	meoprobit vol c_c_subject c_qc_subject if missing(vol, subject, age, sex, v3)==0 ///
		|| v3: c_c_subject c_qc_subject, trace intmethod(mcaghermite)
	
	mixed vol c_c_subject c_qc_subject c_age c_sex ///
		|| v3: c_c_subject c_qc_subject
	estimates store qsubject_b
	mixed vol c_c_subject c_qc_subject c_age c_sex ///
		|| v3:
	estimates store nosubject_b
	lrtest qsubject_b nosubject_b // test whether effect of subj. social class varies between countries	
	mixed vol c_c_subject c_qc_subject if missing(vol, subject, age, sex, v3)==0 ///
		|| v3: c_c_subject c_qc_subject
		

/* --( Regressions to determine correct intercepts for the figures )-- */

use Study6, clear
recode sex (1=-1) (2=1), generate(sexnew)
center age if missing(vol, c_object, age, sex, v3)==0
rename c_age age_obj
center age if missing(vol, c_subject, age, sex, v3)==0
rename c_age age_subj
sum age*

xtmelogit dvol c_object qc_object age_obj sexnew || v3: c_object qc_object
xtmelogit dvol c_subject qc_subject age_subj sexnew || v3: c_subject qc_subject

mixed vol c_object qc_object age_obj sexnew || v3: c_object qc_object
mixed vol c_subject qc_subject age_subj sexnew || v3: c_subject qc_subject
		
			
/* -------------------------   Post hoc analyses    -------------------------- */
* --- (because effcts of obj. & subj. social class vary between countries) ---*
*  -> Ordered probit analyses separately for each country

use Study6, clear

foreach X of numlist 1/2 {
  tab v3 if v3==`X'
  sum c_object if v3==`X' & missing(vol,c_object,age,sex)==0
  oprobit vol c_object qc_object age sex if v3==`X'
  oprobit vol c_subject qc_subject age sex if v3==`X'
  use Study6, clear  
  }
foreach X of numlist 4/4 {
  tab v3 if v3==`X'
  sum c_object if v3==`X' & missing(vol,c_object,age,sex)==0
  oprobit vol c_object qc_object age sex if v3==`X'
  use Study6, clear  
  }
 foreach X of numlist 6/10 {
  tab v3 if v3==`X'
  sum c_object if v3==`X' & missing(vol,c_object,age,sex)==0
  oprobit vol c_object qc_object age sex if v3==`X'
  oprobit vol c_subject qc_subject age sex if v3==`X'
  use Study6, clear  
  }
 foreach X of numlist 11/11 {
  tab v3 if v3==`X'
  sum c_object if v3==`X' & missing(vol,c_object,age,sex)==0
  oprobit vol c_object qc_object age sex if v3==`X'
  use Study6, clear  
  }
 foreach X of numlist 12/22 {
 tab v3 if v3==`X'
  sum c_object if v3==`X' & missing(vol,c_object,age,sex)==0
  oprobit vol c_object qc_object age sex if v3==`X'
  oprobit vol c_subject qc_subject age sex if v3==`X'
  use Study6, clear  
  }
 foreach X of numlist 24/33 {
  tab v3 if v3==`X'
  sum c_object if v3==`X' & missing(vol,c_object,age,sex)==0
  oprobit vol c_object qc_object age sex if v3==`X'
  oprobit vol c_subject qc_subject age sex if v3==`X'
  use Study6, clear  
  }
 
 
 /* --( Supplementary analysis of the effects of indicators of social class )-- */

generate qc_wincome = c_wincome^2
generate qc_degree = c_degree^2
generate qc_siops = c_siops^2

* 1. Probability of volunteering
	xtmelogit dvol c_wincome qc_wincome age sex || v3: c_wincome qc_wincome, or
	xtmelogit dvol c_wincome qc_wincome if missing(dvol, c_wincome, age, sex, v3)==0 ///
		|| v3: c_wincome qc_wincome, or
	xtmelogit dvol c_degree qc_degree age sex || v3: c_degree qc_degree, or
	xtmelogit dvol c_degree qc_degree if missing(dvol, c_degree, age, sex, v3)==0 ///
		|| v3: c_degree qc_degree, or
	xtmelogit dvol c_siops qc_siops age sex || v3: c_siops qc_siops, or
	xtmelogit dvol c_siops qc_siops if missing(dvol, c_siops, age, sex, v3)==0 ///
		|| v3: c_siops qc_siops, or

* 2. Frequency of volunteering
* To run the analyses faster and without errors, it is helpful to center all variables ...
* ... across the sample before starting the calculation.
* However, calculations still take a while

	use Study6, clear
	generate qc_wincome = c_wincome^2
	keep if missing(vol,c_wincome,qc_wincome,age,sex,v3)==0
	center c_wincome qc_wincome age sex
	meoprobit vol c_c_wincome c_qc_wincome c_age c_sex ///
		|| v3: c_c_wincome c_qc_wincome, trace intmethod(mcaghermite)
	mixed vol c_c_wincome c_qc_wincome c_age c_sex ///
		|| v3: c_c_wincome c_qc_wincome
	meoprobit vol c_c_wincome c_qc_wincome if missing(vol, c_wincome, age, sex, v3)==0 ///
		|| v3: c_c_wincome c_qc_wincome, trace intmethod(mcaghermite)
	mixed vol c_c_wincome c_qc_wincome if missing(vol, c_wincome, age, sex, v3)==0 ///
		|| v3: c_c_wincome c_qc_wincome
		
	
	use Study6, clear
	generate qc_degree = c_degree^2
	keep if missing(vol,c_degree,qc_degree,age,sex,v3)==0
	center c_degree qc_degree age sex
	meoprobit vol c_c_degree c_qc_degree c_age c_sex ///
		|| v3: c_c_degree c_qc_degree, trace intmethod(mcaghermite)
	mixed vol c_c_degree c_qc_degree c_age c_sex ///
		|| v3: c_c_degree c_qc_degree
	meoprobit vol c_c_degree c_qc_degree if missing(vol, c_degree, age, sex, v3)==0 ///
		|| v3: c_c_degree c_qc_degree, trace intmethod(mcaghermite)
	mixed vol c_c_degree c_qc_degree if missing(vol, c_degree, age, sex, v3)==0 ///
		|| v3: c_c_degree c_qc_degree
	
	use Study6, clear
	generate qc_siops = c_siops^2
	keep if missing(vol,c_siops,qc_siops,age,sex,v3)==0
	center c_siops qc_siops age sex
	meoprobit vol c_c_siops c_qc_siops c_age c_sex ///
		|| v3: c_c_siops c_qc_siops, trace intmethod(mcaghermite)
	mixed vol c_c_siops c_qc_siops c_age c_sex ///
		|| v3: c_c_siops c_qc_siops
	meoprobit vol c_c_siops c_qc_siops if missing(vol, c_siops, age, sex, v3)==0 ///
		|| v3: c_c_siops c_qc_siops, trace intmethod(mcaghermite)
	mixed vol c_c_siops c_qc_siops if missing(vol, c_siops, age, sex, v3)==0 ///
		|| v3: c_c_siops c_qc_siops
		

 log close
