setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study7 <- read.dta('Study7.dta')

# Convert into csv-File
write.csv(study7, "C:/Users/User/Desktop/Study 7/Study7.csv", row.names=TRUE)

# possibly create Figure10 that contains all 4 panels
postscript(file="Figure10.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(2,2))

##### Figure A ########
attach(study7)
order <- order(dobject)
order.object <- dobject[order]
order.objehb <- objehb[order]
plot(order.object, order.objehb,
main="Mean scale value of\n Everyday Helping\n(per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Scale value", 
xaxs="i",
mgp=c(2.65,1,0),
xlim = c(0.5, 10), 
ylim = c(8.5, 11.3), type = "l", lwd=1, bty="l", yaxs="i", yaxp=c(8,12,4), xaxp=c(0,10,10), cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("A",side=3, line = 1.5, adj=-0.12, cex=1.44, font=2 )
points(order.object, order.objehb, cex=0.7, pch=20)
detach(study7)

##### Figure B ########
loehb <- with(study7, loess(ehb ~ c_object, span=0.8, degree=1))
pehb <- predict(loehb, data.frame(c_object = seq(-2.48, 2.69, 0.01)))
plot(seq(-2.48, 2.69,0.01),pehb, 
main="Scale Value of\n Everyday Helping\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Scale value", 
mgp=c(2.65,1,0),
xlim = c(-3, 3), 
ylim = c(8.5, 11.3), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, yaxp=c(8,12,4), cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("B",side=3, line = 1.5, adj=-0.12, cex=1.44, font=2 )

##### Figure C ########
attach(study7)
order <- order(subject)
order.subject <- subject[order]
order.subjehb <- subjehb[order]
plot(order.subject, order.subjehb,
main="Mean scale value of\n Everyday Helping\n(per category of subj. soc. class)", 
xlab="Subj. social class", ylab="Scale value",
xaxt="n", xaxp=c(1,4,3), 
mgp=c(2.65,1,0),
ylim = c(8.5, 11.3), type = "l", lwd=1, bty="l", yaxs="i", yaxp=c(8,12,4), cex.lab = 1, cex.axis = 1, cex.main=1.1)
axis(1, 1:4, labels=c("Lower\nclass", "Working\nclass", "Middle\nclass", "Upper\nclass"), mgp=c(2.65,1.5,0), cex.axis=1.0)
mtext("C",side=3, line = 1.5, adj=-0.12, cex=1.44, font=2 )
points(order.subject, order.subjehb,cex=0.7, pch=20)
detach(study7)

##### Figure D ########
x <- seq(-2.49,2.69,0.01)
# determine "average year" for intercept
9.8448+((1.1998+.2177)/3)
yobj <- 10.3173+0.3974*x-0.11*x^2

xsub <- seq(-2.21,2.32,0.01)
# determine "average year" for intercept
9.7269+((1.213+.2381)/3)
ysubj <- 10.2106+.0579*xsub+0.0055*xsub^2

plot(x,yobj,
     main="Predicted values\nof the scale value of Everyday Helping", 
     xlab="Standardized social class", ylab="Scale value", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(8.5, 11.3), yaxp=c(8,12,4), 
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=1.1)
mtext("D",side=3, line = 1.5, adj=-0.12, cex=1.44, font=2 )
lines(xsub,ysubj,
      type = "l", lwd=1, lty=2)     
legend (-0.9, 9.5, c("subj. social class", "obj. social class"), lty=c(2,1))

dev.off()