setwd('path/to/the/directory/you/saved/the/Stata/file/')

library(graphics)
library(foreign)

study8 <- read.dta('Study8.dta')

# Convert into csv-File
write.csv(study8, "C:/Users/User/Desktop/Study 8/Study8.csv", row.names=TRUE)

player1 <- study8[study8$player==1,]
player2 <- study8[study8$player==3,]

# possibly create Figure11 that contains all 3 panels
postscript(file="Figure11.eps", width=8, height=8, horizontal=FALSE)
par(mfrow=c(3,3))

######## Figure A #########
attach(player1)
order <- order(dclass)
order.class <- dclass[order]
order.give1 <- dgive[order]
plot(order.class,order.give1,
main="Number of points sent\n(means per decile of obj. soc. class)", 
xlab="Deciles of obj. social class", ylab="Number of points sent", 
mgp=c(2.65,1,0),
xlim = c(1, 10), 
ylim = c(3, 7), type = "l", lwd=1, lty=1, yaxs="i", bty="l", xaxp=c(1,10,9), yaxp=c(2,8,6), cex.lab = 1, cex.axis = 1, cex.main=0.95)
mtext("A",side=3, line = 1.5, adj=-0.12, cex=1, font=2 )
points(order.class,order.give1,cex=0.7, pch=20)
detach(player1)
attach(player2)
order <- order(dclass)
order.class <- dclass[order]
order.give2 <- dresid[order]
lines(order.class,order.give2,
lwd=1, lty=2)
points(order.class,order.give2,cex=0.7, pch=20)
detach(player2)
legend (1.3, 6.9, c("Player 1", "Player 2"), lty=c(1,2), cex=0.9)


######## Figure B ##########
loplayer1 <- with(player1, loess(pgive ~ c_soclass, span=0.8, degree=1))
player1 <- predict(loplayer1, data.frame(c_soclass = seq(-2.24, 2.86, 0.01)))
plot(seq(-2.24, 2.86,0.01),player1, 
main="Number of points sent\n(locally regressed on obj. soc. class)", 
xlab="Standardized obj. social class", ylab="Number of points sent", 
mgp=c(2.65,1,0),
xlim = c(-3, 3), 
ylim = c(3, 7), 
type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, yaxp=c(2,8,6), cex.lab = 1, cex.axis = 1, cex.main=0.95)
mtext("B",side=3, line = 1.5, adj=-0.12, cex=1, font=2 )
loplayer2 <- with(player2, loess(resid ~ c_soclass, span=0.8, degree=1))
player2 <- predict(loplayer2, data.frame(c_soclass = seq(-2.24, 2.53, 0.01)))
lines(seq(-2.24, 2.53,0.01),player2, 
lwd=1, lty=2)
legend (-2.5, 6.9, c("Player 1", "Player 2"), lty=c(1,2), cex=0.9)

########## Figure C ##########
xpl1 <- seq(-2.24,2.86,0.01)
# determine "average year" for intercept
5.1252+((.3505+.5788)/3)
ypl1 <- 5.4350+0.468*xpl1-0.0238*xpl1^2

xpl2 <- seq(-2.24,2.53,0.01)
# determine "average year" for intercept
4.9881+((-.0650+.0558)/3)
ypl2 <- 4.985+.4208*xpl2-0.0751*xpl2^2

plot(xpl1,ypl1,
     main="Predicted values of the\nscale value of Everyday Helping", 
     xlab="Standardized obj. social class", ylab="Scale value", 
     mgp=c(2.65,1,0),
     xlim = c(-3, 3),
     ylim = c(3, 7), yaxp=c(2,8,6), 
     type = "l", lwd=1, xaxs="i", yaxs="i", bty="l", lty=1, cex.lab = 1, cex.axis = 1, cex.main=0.95)
mtext("C",side=3, line = 1.5, adj=-0.12, cex=1, font=2 )
lines(xpl2,ypl2,
      type = "l", lwd=1, lty=2)     
legend (-2.5, 6.9, c("Player 1", "Player 2"), lty=c(1,2), cex=0.9)

dev.off()