***** To get access to the SOEP data, you have to conclude a data distribution contract with DIW Berlin ***
***** For more details, see http://www.diw.de/en/diw_02.c.222516.en/data.html *****************************
***********************************************************************************************************
***** For our analyses, we used data for years 1984-2012, Version 29, 2013 ********************************
***********************************************************************************************************

/*                                                                       */
/* -----        How to customize the paths and options:   -----          */
/* -----        Some further explanations:                -----          */                                                                           
/*  The following                                                        */                              
/*                                                                       */                 
/*  global macros (in stata),                                            */                                          
/*                                                                       */                 
/*  define the locations for the original SOEP DATA, the directory       */                                                                               
/*  for temporary files and the destination of the resulting data file.  */                                                                                    
/*                                                                       */                 
/*  MY_IN_PATH   = "path/to/your/SOEP/directory/"                        */                                                              
/*  MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"       */                                                                               
/*  MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"      */                                                                                
/*                                                                       */                 
/*  The correct specification of the path depends on your Operating      */                                                                                
/*  System and on your SOEP installation, but be sure to use a           */                                                                           
/*  TRAILING backslash ("\", within Windows) or a                        */                                                              
/*  TRAILING forward slash ("/", within Unix/Linux).                     */                                                                 
/*                                                                       */                 
/*  You can also change the name for the resulting data file with the    */                                                                                  
/*  variable MY_OUT_FILE and the name for the log file (only with        */                                                                              
/*  stata, variable MY_LOG_FILE).                                        */                                              
/* ----------------------------------------------------------------      */                                                                                


/* -----   Here you can customize the paths and options:   ----- */

global MY_IN_PATH   = "path/to/your/SOEP/directory/"                                                             
global MY_OUT_PATH  = "path/to/the/directory/for/the/resulting/file/"                                                                             
global MY_TEMP_PATH = "path/to/the/directory/for/the/temporary/files/"

global MY_OUT_FILE  ${MY_OUT_PATH}\Study 8\Study8.dta
global MY_LOG_FILE  ${MY_OUT_PATH}\Study 8\Study8_data_preparation.log

log using "${MY_LOG_FILE}", text replace
set more off


/* ---------------  Trustgame 2003 ---------------------------*/

use  "${MY_IN_PATH}trust.dta"

drop if (svyyear==2004) | (svyyear==2005)
generate player03 = spieler
generate pget03 = pget
generate pgive03 = pgive
generate svyyear03 = svyyear
generate euro03 = euro

save  "${MY_IN_PATH}trust03.dta", replace
clear

/* ---------------  Trustgame 2004 ---------------------------*/

use  "${MY_IN_PATH}trust.dta"

drop if (svyyear==2003) | (svyyear==2005)
generate player04 = spieler
generate pget04 = pget
generate pgive04 = pgive
generate svyyear04 = svyyear
generate euro04 = euro

save  "${MY_IN_PATH}trust04.dta", replace
clear

/* ---------------  Trustgame 2005 ---------------------------*/

use  "${MY_IN_PATH}trust.dta"

drop if (svyyear==2004) | (svyyear==2003)
generate player05 = spieler
generate pget05 = pget
generate pgive05 = pgive
generate svyyear05 = svyyear
generate euro05 = euro

save  "${MY_IN_PATH}trust05.dta", replace
clear


/* ----------------[ automatically pull PPFAD ]----------------- */

use    hhnr    persnr  sex  gebjahr psample ///
       thhnr   uhhnr   vhhnr   whhnr   ///  
       tnetto  unetto  vnetto  wnetto  /// 
       tpop    upop    vpop    wpop    ///
using  "${MY_IN_PATH}ppfad.dta"

/* --------------[ balanced / unbalanced design ]--------------- */

keep if ( ( unetto > 0 & unetto < 40 ) | ( vnetto > 0 & vnetto < 40 ) |   ///
          ( wnetto > 0 & wnetto < 40 ) | ( tnetto > 0 & tnetto < 40 ))

/* -----------------[ private housholds only.]------------------ */

/* -- start comment
keep if ( ( bapop == 1 | bapop == 2 ) | ( tpop == 1 | tpop == 2 ) |
          ( upop == 1 | upop == 2 ) | ( vpop == 1 | vpop == 2 ) |
          ( wpop == 1 | wpop == 2 ) | ( zpop == 1 | zpop == 2 ) );
*/
/* -----------------------[ sort ppfad ]------------------------ */

sort persnr
save "${MY_TEMP_PATH}ppfad.dta", replace
clear

/* -----------------[ automatically pull PHRF ]----------------- */

use    hhnr    persnr  prgroup   ///
       tphrf   uphrf   vphrf   wphrf   ///
using  "${MY_IN_PATH}phrf.dta"

sort  persnr
save  "${MY_TEMP_PATH}phrf.dta", replace
clear

/* --------------[ automatically create pmaster ]--------------- */

use    "${MY_TEMP_PATH}ppfad.dta"
merge  persnr   ///
using  "${MY_TEMP_PATH}phrf.dta"

drop   if _merge == 2
drop   _merge
erase  "${MY_TEMP_PATH}ppfad.dta"
erase  "${MY_TEMP_PATH}phrf.dta"
sort   persnr
save   "${MY_TEMP_PATH}pmaster.dta", replace


/* -----------------------( pull tpgen )------------------------ */

use    hhnr    thhnr   persnr    ///
       siops03 isced03  ///
using "${MY_IN_PATH}tpgen.dta"

sort persnr
save "${MY_TEMP_PATH}tpgen.dta", replace
clear

/* ----------------------( pull tpequiv )----------------------- */

use    hhnr    thhnr   persnr    ///
       d1110103 d1110503 d1110603 h1110103  ///
using "${MY_IN_PATH}tpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}tpequiv.dta", replace
clear

/* -----------------------( pull upgen )------------------------ */

use    hhnr    uhhnr   persnr    ///
       siops04 isced04  ///
using "${MY_IN_PATH}upgen.dta"

sort persnr
save "${MY_TEMP_PATH}upgen.dta", replace
clear

/* ----------------------( pull upequiv )----------------------- */

use    hhnr    uhhnr   persnr    ///
       d1110104 d1110504 d1110604 i1110204 h1110104  ///
using "${MY_IN_PATH}upequiv.dta"

sort persnr
save "${MY_TEMP_PATH}upequiv.dta", replace
clear


/* -----------------------( pull vpgen )------------------------ */

use    hhnr    vhhnr   persnr     ///
       siops05 isced05   ///
using "${MY_IN_PATH}vpgen.dta"

sort persnr
save "${MY_TEMP_PATH}vpgen.dta", replace
clear

/* ----------------------( pull vpequiv )----------------------- */

use    hhnr    vhhnr   persnr     ///
       d1110105 d1110505 d1110605 i1110205 h1110105   ///
using "${MY_IN_PATH}vpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}vpequiv.dta", replace
clear

/* ----------------------( pull wpequiv )----------------------- */

use    hhnr    whhnr   persnr     ///
       i1110206   ///
using "${MY_IN_PATH}wpequiv.dta"

sort persnr
save "${MY_TEMP_PATH}wpequiv.dta", replace
clear


/* -------------------------( pull trust03 )------------------------- */

use    hhnr    persnr  svyyear03   ///
       player03  pgive03  pget03  euro03   ///
using "${MY_IN_PATH}trust03.dta"

sort persnr
save "${MY_TEMP_PATH}trust03.dta", replace
clear

/* -------------------------( pull trust04 )------------------------- */

use    hhnr    persnr  svyyear04   ///
       player04  pgive04  pget04   euro04 ///
using "${MY_IN_PATH}trust04.dta"

sort persnr
save "${MY_TEMP_PATH}trust04.dta", replace
clear

/* -------------------------( pull trust05 )------------------------- */

use    hhnr    persnr  svyyear05   ///
       player05  pgive05  pget05  euro05  ///
using "${MY_IN_PATH}trust05.dta"

sort persnr
save "${MY_TEMP_PATH}trust05.dta", replace
clear


/* -----------------( Now merge all together )------------------ */

use   "${MY_TEMP_PATH}pmaster.dta"
erase "${MY_TEMP_PATH}pmaster.dta"

/* -----------( merge together by person: ALL Waves )----------- */


/* -----------------------( merge TPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}tpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}tpgen.dta"

/* ----------------------( merge TPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}tpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}tpequiv.dta"

/* -----------------------( merge UPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}upgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}upgen.dta"

/* ----------------------( merge UPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}upequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}upequiv.dta"


/* -----------------------( merge VPGEN )----------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}vpgen.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}vpgen.dta"

/* ----------------------( merge VPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}vpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}vpequiv.dta"

/* ----------------------( merge WPEQUIV )---------------------- */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}wpequiv.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}wpequiv.dta"


/* ------------------------( merge trust03 )------------------------ */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}trust03.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}trust03.dta"

/* ------------------------( merge trust04 )------------------------ */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}trust04.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}trust04.dta"

/* ------------------------( merge trust05 )------------------------ */

          
sort  persnr
merge persnr   ///
using "${MY_TEMP_PATH}trust05.dta"
drop   if _merge == 2
drop   _merge
erase "${MY_TEMP_PATH}trust05.dta"


/* --------------------------( Merging done! )-------------------------- */

label data "SOEPINFO: Magic at Work! http://panel.gsoep.de/soepinfo/"
save  "${MY_OUT_FILE}", replace
desc

/* --------------------------( Rename variables to tranform data-matrix into long-format  )-------------------------- */

soepren thhnr uhhnr vhhnr whhnr, ///
	newstub(hnr) waves(2003 2004 2005 2006)
soepren tpop upop vpop wpop, ///
	newstub(pop) waves(2003 2004 2005 2006)
soepren tnetto unetto vnetto wnetto, ///
	newstub(netto) waves(2003 2004 2005 2006)

soepren d1110103 d1110104 d1110105, ///
	newstub(age) waves(2003 2004 2005)
soepren d1110603 d1110604 d1110605, ///
	newstub(personshh) waves(2003 2004 2005)
soepren h1110103 h1110104 h1110105, ///
	newstub(childhh) waves(2003 2004 2005)
soepren d1110503 d1110504 d1110505, ///
	newstub(relation) waves(2003 2004 2005)

soepren isced03 isced04 isced05, ///
	newstub(isced) waves(2003 2004 2005)
soepren siops03 siops04 siops05, ///
	newstub(siops) waves(2003 2004 2005)
* Rename income variable 
* (and therby change the year of the assessment of income to the year income was actually earned)
soepren i1110204 i1110205 i1110206, ///
	newstub(hhincome) waves(2003 2004 2005)

soepren player03 player04 player05, newstub(player) waves(2003 2004 2005)
soepren pget03 pget04 pget05, newstub(pget) waves(2003 2004 2005)
soepren pgive03 pgive04 pgive05, newstub(pgive) waves(2003 2004 2005)
soepren euro03 euro04 euro05, newstub(euro) waves(2003 2004 2005)

drop svyyear*
drop gebjahr
drop prgroup
drop tphrf-wphrf

/* --------------------------( Reshape into long-format  )-------------------------- */

reshape long hnr netto pop age siops isced hhincome childhh personshh relation ///
	player pget pgive euro, i(persnr) j(year)
xtset persnr year


/* --------------------------( Decode missing values  )-------------------------- */

mvdecode age sex siops isced pgive pget euro, mv (-2=.\-1=.)


/* --------------------------( Create measure of obj. social class  )-------------------------- */

* 1. standardize education and job prestige per year (but first set those "in school" to missing)
mvdecode isced, mv (0=.)
by year, sort: center isced siops, standardize

* 2. Weigthed annual after-tax hh-income
* 	a, generate OECD equivalence weight
	generate oecd = (1 + 0.7 * (personshh - childhh - 1) + 0.5 * childhh)
* 	b, divide income by OECD weight
	generate wincome = round(hhincome/oecd)
* 	c, recode weighted income measure into a categorical income measure similar to Piff et al. (2010)
	sum oecd if relation==1
	recode wincome (0/6000 = 1) (6001/10000 = 2) (10001/14000 = 3) (14001/20000 = 4) ///
	(20001/30000 = 5) (30001/40000 = 6) (40001/60000 = 7) (60001/max = 8) if wincome<.
	hist wincome
*  d, standardize this income measure
	by year, sort: center wincome, standardize

* 3. generate (and standize per year) composite measure of obj. social class
egen soclass = rowmean(c_wincome c_isced c_siops)
by year, sort: center soclass, standardize
* 4. calculate squared obj. social class measure
generate qc_soclass = c_soclass^2


/* -----------( Prepare data for the figures (that are drawn in R)  )----------------- */
 
xtset, clear
keep if year==2003 | year==2004 | year==2005
xtile dclass = c_soclass, n(10)
keep if (missing(age, sex, pgive, c_soclass)==0 & player==1) | ///
		(missing(age, sex, pgive, pget, c_soclass)==0 & player==3)
egen dgive = mean(pgive) if player==1, by(dclass)
regress pgive pget if player==3
predict resi, resid
sum resi
sum pgive if player==3
generate resid = resi + 4.896 if player==3
egen dresid = mean(resid) if player==3, by(dclass)


/* --------------( Anonymize the person number )--------------- */

bysort persnr: generate nnn = 1/_N
generate snnn = sum(nnn)
bysort persnr: replace persnr = snnn[_N]

drop nnn snnn


/* --------------( Delete variables that are not needed for final analyses )--------------- */

keep year persnr wincome isced siops age sex pgive pget euro player c_soclass qc_soclass ///
dclass dgive resid dresid c_wincome c_isced c_siops

label variable persnr "anonymized person number"
label variable year	"year of measurement"
label variable sex	"respondent's sex"
label variable age	"age of respondent"
label variable wincome	"income category"
label variable isced "isced category of respondent (if not in school)"
label variable siops "siops category of respondent"
label variable c_soclass "standardized objective social class"
label variable qc_soclass "squared standardized objective social class"
label variable player "player in trust game (1 = player 1; 3 = player 2)"
label variable pget	"points received"
label variable pgive "points sent"
label variable euro	"individual payoff"
label variable dclass "decile of objective social class"
label variable resid "points sent controlled for points received (player 2)"
label variable dgive "mean points sent per decile of objective social class (player 1)"
label variable dresid "mean points sent per decile of objective social class (player 2)"


/* --------------------------( save file for  (re)analyses  )-------------------------- */
saveold  "${MY_OUT_FILE}", replace

log close
